function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() : typeof define === 'function' && define.amd ? define(factory) : (global = global || self, global.foxsdk = factory());
})(this, function () {
  /**
   * @created by anonymous 2019-12-28
   * @updated by
   * @description 工具方法
   */

  /**
   * SDK日志输出类
   */
  var Logger = function () {
    var emptyFn = function () {};

    this.fn = window.console || {
      debug: emptyFn,
      info: emptyFn,
      warn: emptyFn,
      error: emptyFn
    };
    this.fn.debug = this.fn.debug || this.fn.info;
    this.configLevel();
  };

  _extends(Logger.prototype, {
    configLevel: function (options) {
      options = options || {
        info: true,
        debug: true,
        warn: true,
        error: true
      };

      _extends(this, {
        level: options
      });
    },
    debug: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.debug && (ref = this.fn).debug.apply(ref, args);
    },
    info: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.info && (ref = this.fn).info.apply(ref, args);
    },
    warn: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.warn && (ref = this.fn).warn.apply(ref, args);
    },
    error: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.error && (ref = this.fn).error.apply(ref, args);
    }
  });
  /** 实例化logger */


  var logger = new Logger();
  /**
   * 原生返回状态码
   */

  var NATIVE_STATUS_CODE = {
    /**
     * 成功
     */
    OK: '0',

    /**
     * 持续调用
     */
    PROCESS: '1',

    /**
     * 非0|1都表示失败
     * 10004: payload数据解析异常
     */
    FAIL: '10004' // 更多错误码
    // http://192.168.251.162:8090/pages/viewpage.action?pageId=7603575

  };
  /**
   * 每生成一个ID，则自增一次
   */

  var UNIQUE_ID = 0;
  /**
   * 生成唯一的ID
   * @param {*} prefix id前缀，默认uid
   */

  var uuid = function (prefix) {
    if (prefix === void 0) prefix = 'uid';
    return prefix + UNIQUE_ID++ + new Date().getTime();
  };
  /**
   * 对象转成URL参数
   */


  var addUrlParams = function (params) {
    var paramsData = '';
    Object.keys(params).forEach(function (key) {
      paramsData += key + '=' + encodeURIComponent(params[key]) + '&';
    });
    return paramsData.substring(0, paramsData.length - 1);
  };
  /**
   * SDK错误
   * @param {*} status 错误码
   * @param {*} message 错误信息
   */


  var SdkError = function (status, message) {
    this.status = status;
    this.message = message;
    logger.warn('SdkError:', '{"status": "' + this.status + '","message": "' + this.message + '"}');
  };
  /**
   * 输出错误信息
   */


  SdkError.prototype.toString = function () {
    return 'SdkError: {"status": "' + this.status + '","message": "' + this.message + '"}';
  };
  /**
   * 延迟执行任务
   * @param {*} fn 延迟执行方法
   * @param {*} millisecond 延迟时间毫秒
   */


  var delayTask = function (fn, millisecond) {
    var id = setTimeout(function () {
      clearTask(id);
      id = null;
      fn();
    }, millisecond);
    return id;
  };
  /**
   * 清除延迟处理
   * @param {*} id 延迟任务ID
   */


  var clearTask = function (id) {
    id !== undefined && window.clearTimeout(id);
  };
  /**
   * JS继承
   */


  var extendClazz = function (supClazz, subClazz) {
    var proto = Object.create(supClazz.prototype);
    proto.constructor = subClazz;
    subClazz.prototype = proto;
  };
  /**
   * 导出工具方法对象
   */


  var utils = {
    logger: logger,
    NATIVE_STATUS_CODE: NATIVE_STATUS_CODE,
    SdkError: SdkError,
    delayTask: delayTask,
    clearTask: clearTask,
    uuid: uuid,
    addUrlParams: addUrlParams,
    extendClazz: extendClazz
  };
  var logger$1 = utils.logger;
  var SdkError$1 = utils.SdkError;
  var NATIVE_STATUS_CODE$1 = utils.NATIVE_STATUS_CODE;
  var __FOX_COMMAND_URL__ = 'https://__wvjb_queue_message__';
  window.__FOX_CALLBACKS__ = window.__FOX_CALLBACKS__ || {}; // JS调用native接口时的回调方法，临时存储

  window.__FOX_EVENT_CALLBACKS__ = window.__FOX_EVENT_CALLBACKS__ || {}; // JS调用监听native事件接口的回调方法，临时存储

  var isIOS = window.__FOX_PLATFORM__ === 'iOS'; // Android 页面load前不能直接注入变量（仅能注入方法对象），故直接使用__FOX_NATIVE_CALL__.call
  // const isAndroid = window.__FOX_PLATFORM__ === 'Android';

  var isAndroid = window.__FOX_NATIVE_CALL__ && typeof window.__FOX_NATIVE_CALL__.call === 'function';
  /**
   * 创建桥接的iframe
   * @returns bridgeiframe
   */

  var createExecIframe = function () {
    var execIframe = document.createElement('iframe');
    execIframe.style.display = 'none'; // 创建iframe并放到body里面去

    var appendToBody = function (iframe) {
      var body = document.body;

      if (body) {
        iframe.parentNode || body.appendChild(iframe);
      } else {
        window.setTimeout(function () {
          appendToBody(iframe);
        }, 100);
      }
    };

    appendToBody(execIframe);
    return execIframe;
  };

  var callAndroid = function (clazz, action, data, callbackid) {
    /* eslint no-undef: 0 */
    if (!window.__FOX_NATIVE_CALL__) {
      throw new SdkError$1('10005', 'The current environment cannot call the bridge layer. Because “window.__FOX_NATIVE_CALL__” does not available on Android.');
    } // JS调用原生方法
    // @param {String} classname 类名
    // @param {String} action 方法名
    // @param {String} data 传递数据
    // @param {String} callbackid 回调方法ID


    window.__FOX_NATIVE_CALL__.call(clazz, action, data, callbackid);
  };

  var callIos = function (clazz, action, data, callbackid) {
    var urlParams = utils.addUrlParams({
      classname: clazz,
      action: action,
      data: data,
      callbackid: callbackid
    });
    var execIframe = createExecIframe();
    execIframe.src = __FOX_COMMAND_URL__ + '?' + urlParams; // 移除DOM中的调用原生桥接

    window.setTimeout(function () {
      execIframe.parentNode && execIframe.parentNode.removeChild(execIframe);
    }, 100);
  };
  /**
   * JS调用原生方法
   * @param {String} clazz 类名
   * @param {String} action 方法名
   * @param {String/Object} data 传递数据
   * @param {Function} callback 回调方法
   * @returns {String} callbackid 回调id
   */


  var call = function (clazz, action, data, callback) {
    var callbackid = utils.uuid('cbid');
    data = typeof data === 'string' ? data : JSON.stringify(data);
    window.__FOX_CALLBACKS__[callbackid] = callback;
    logger$1.debug('X====bridge-call====\n callbackid: ' + callbackid + ',\n clazz: ' + clazz + ',\n action: ' + action + ',\n data: ' + data + '');

    if (!isAndroid && !isIOS) {
      throw new SdkError$1('10005', 'The current environment cannot call the bridge layer.');
    }

    isIOS ? callIos(clazz, action, data, callbackid) : callAndroid(clazz, action, data, callbackid);
    return callbackid;
  };
  /**
   * 移除指定callbackid对应的回调方法，主要是针对于
   * @param {*} callbackid 回调ID
   */


  var removeCb = function (callbackid, callbacks) {
    callbacks = callbacks || window.__FOX_CALLBACKS__;
    callbacks[callbackid] = null;
    delete callbacks[callbackid];
  };
  /**
   * 子线程回调
   * @param {*} callbacks JS调用native接口时的回调方法，临时存储
   * @param {*} callbackid 唯一识别码
   * @param {*} status 错误码：OK: 成功, FAIL: 失败, PROCESS: 持续进行中
   * @param {*} message 错误信息
   * @param {*} payload 回调json数据
   */


  var nextTick = function (callbacks, callbackid, status, message, payload) {
    try {
      payload = JSON.parse(payload);
    } catch (e) {
      logger$1.debug('X====bridge-nextTick==== \n Native return payload data is not in standard JSON format. \n ' + e);
      status = NATIVE_STATUS_CODE$1.FAIL;
      message = 'Native return payload data is not in standard JSON format.';
    }

    var retObj = {
      status: status,
      message: message,
      payload: payload
    };
    var cb = callbacks[callbackid];

    if (status === NATIVE_STATUS_CODE$1.PROCESS) {
      retObj.status = NATIVE_STATUS_CODE$1.OK;
    } else {
      removeCb(callbackid, callbacks);
    }

    logger$1.debug('X====bridge-nextTick====00');
    cb(retObj);
  };
  /**
   * 原生调用JS的回调方法，最终会挂载到: window.__FOX_NATIVE_EVAL__
   * @param {*} callbackid 唯一识别码
   * @param {*} status 错误码：0: 成功, 1: 持续进行中, 其它状态是失败
   * @param {*} message 错误信息
   * @param {*} payload 回调json数据
   */


  var nativeEval = function (callbackid, status, message, payload) {
    logger$1.debug('X====bridge-nativeEval==== \n callbackid: ' + callbackid + ',\n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload + '');
    payload = payload || '{}';

    if (window.__FOX_CALLBACKS__[callbackid]) {
      window.setTimeout(function () {
        nextTick(window.__FOX_CALLBACKS__, callbackid, status, message, payload);
      }, 1);
    }
  };

  var bridge$1 = {
    call: call,
    nativeEval: nativeEval,
    removeCb: removeCb
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:39:31
   * @Description: 网络请求
   */

  var http = {
    /**
     * @description 发起网络请求
     * @type {Function}
     * @param {String} data
     * {
     *    url : xxxx,
     *    method : ”POST”,
     *    header : { device_id : ”212121313”},
     *    parameter : {search : ”yuxin”}
     * }
     */
    request: function (data, cb) {
      bridge$1.call('Request', 'request', data, cb);
    },

    /**
     * @description 取消网络请求
     * @type {Function}
     * @param {String} data
     * {
     *    url : xxxx,
     * }
     */
    doCancel: function (data, cb) {
      bridge$1.call('Request', 'doCancel', data, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-07 15:23:13
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:37:39
   * @Description: 文件下载
   */

  var logger$2 = utils.logger;
  var NATIVE_STATUS_CODE$2 = utils.NATIVE_STATUS_CODE;
  /**
   * 下载任务列表
   */

  var __DOWNLOAD_TASK_LIST__ = {};
  /**
   * 下载状态
   */

  var DownloadState = {
    /**
     * 下载任务未开始
     */
    Undefined: -1001,

    /**
     * 所有下载任务
     */
    All: -1,

    /**
     * 下载任务开始调度
     */
    Start: 0,

    /**
     * 下载任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 下载任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 下载任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 下载任务已完成（成功）
     */
    Finished: 4,

    /**
     * 下载任务已暂停
     */
    Pause: 5,

    /**
     * 下载任务发生异常
     */
    Error: 6
  };
  /**
   * 下载任务对象
   */

  var DownloadTask = function (options) {
    /**
     * 下载任务TaskId
     */
    this.identify = utils.uuid('dtask');
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 网络请求类型
     * 支持http协议的“GET”、“POST”，默认为“GET”请求。
     */

    this.method = this.options.method || 'get';
    /**
     * POST请求时提交的数据
     * 仅在网络请求类型method设置为"POST"时有效，"GET"请求时忽略此数据。
     */

    this.data = this.options.data || '';
    /**
     * 设置下载请求的HTTP头数据
     */

    this.header = this.options.header || {};
    /**
     * 下载文件保存的路径
     * 保存文件路径仅支持以"_downloads/"、"_doc/"、"_documents/"开头的字符串。
     * 文件路径以文件后缀名结尾（如"_doc/download/a.doc"）表明指定保存文件目录及名称，
     * 以“/”结尾则认为指定保存文件的目录（此时程序自动生成文件名）。
     * 默认保存目录为（"_downloads"），并自动生成文件名称。
     */

    this.filename = this.options.filename || '_downloads/';
    /**
     * 下载任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是下载任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 下载任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 下载任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 下载任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.totalSize = 0;
    this.downloadedSize = 0;
    /**
     * 下载任务当前状态
     */

    this.state = -1001;
    /**
     * 下载任务完成回调
     * @param {DownloadTask} task 下载任务对象
     */

    this.completedCb = options.completedCb || function (task) {};
    /**
     * 下载任务状态变化时执行的回调
     * @param {DownloadTask} task 下载任务对象
     */


    this.stateChangeCb = function (task) {};
  };
  /**
   * 下载任务结束时调用（任务完成、任务取消、清除）
   * @param {Object} download 下载任务对象
   * @param {Object} resonse {status,message} 返回对象
   */


  var deleteTask = function (task) {
    delete __DOWNLOAD_TASK_LIST__[task.identify];
  };
  /**
   * 监听下载任务状态回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerCallback.call(task, options);
   */


  var handlerCallback = function (options) {
    this.filename = options.filename || this.filename;
    this.state = options.state || this.state;
    this.downloadedSize = options.downloadedSize || this.downloadedSize;
    this.totalSize = options.totalSize || this.totalSize; // identify
    // url
    // options
    // 下载任务状态变化回调函数，在下载任务状态发生变化时调用

    this.stateChangeCb(this); // 下载任务完成清除下载任务队列

    this.state == DownloadState.Finished && deleteTask(this); // 下载任务完成、下载任务失败，都调用业务回调

    if (this.state == DownloadState.Finished || this.state == DownloadState.Error) {
      this.completedCb(this);
    }
  };
  /**
   * DownloadState.Finished 下载任务完成，该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * DownloadState.Error 下载任务发生异常，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var addStateChange = function (task) {
    bridge$1.call('Downloader', 'stateChanged', {
      identify: task.identify
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$2.OK || status === NATIVE_STATUS_CODE$2.PROCESS) {
        handlerCallback.call(task, payload.download);
      } else {
        deleteTask(task);
        logger$2.debug('====downloader-stateChanged====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };
  /**
   * 生成createDownload请求参数
   */


  var getDownloadOptions = function (task) {
    return {
      url: task.url,
      options: {
        identify: task.identify,
        method: task.method,
        data: task.data,
        header: task.header,
        filename: task.filename,
        priority: task.priority,
        timeout: task.timeout,
        retry: task.retry,
        retryInterval: task.retryInterval
      }
    };
  };

  _extends(DownloadTask.prototype, {
    /**
     * 开始下载任务
     */
    start: function () {
      var _this = this;

      bridge$1.call('Downloader', 'start', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停下载任务
     */
    pause: function () {
      var _this = this;

      bridge$1.call('Downloader', 'pause', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复下载任务
     */
    resume: function () {
      var _this = this;

      bridge$1.call('Downloader', 'resume', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 取消下载任务，
     */
    abort: function () {
      var _this = this;

      bridge$1.call('Downloader', 'abort', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
          deleteTask(_this);
        } else {
          logger$2.debug('====downloader-abort====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 下载任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    }
  });

  var downloader = {
    DownloadState: DownloadState,

    /**
     * 新建下载任务
     * @param {String} url 要下载文件资源地址
     * @param {Object} options 下载任务的参数，可选
     * @param {Function} completedCb 下载任务完成回调函数，回调参数为task
     */
    createDownload: function (url, options, completedCb) {
      if (typeof url != 'string') {
        return null;
      }

      options = options || {};
      options.url = url;
      options.completedCb = completedCb;
      var task = new DownloadTask(options);
      __DOWNLOAD_TASK_LIST__[task.identify] = task;
      var data = getDownloadOptions(task);
      bridge$1.call('Downloader', 'createDownload', data, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(task, payload.download);
          addStateChange(task);
        } else {
          logger$2.debug('====downloader-createDownload====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
          deleteTask(task);
        }
      });
      return task;
    },

    /**
     * 开始所有下载任务
     */
    startAll: function () {
      bridge$1.call('Downloader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
          });
        } else {
          logger$2.debug('====downloader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 清除下载任务
     * @param {DownloadState} state 状态
     */
    clear: function (state) {
      state = state || this.DownloadState.All;
      bridge$1.call('Downloader', 'clear', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
            deleteTask(task);
          });
        } else {
          logger$2.debug('====downloader-clear====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 枚举下载任务
     * @param {DownloadState} state 状态
     * @param {Function} cb 回调
     */
    enumerate: function (state, cb) {
      state = state || this.DownloadState.All;
      bridge$1.call('Downloader', 'enumerate', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          var tasks = [];
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
            tasks.push(task);
          });
          cb(tasks);
        } else {
          logger$2.debug('====downloader-enumerate====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-07 15:23:13
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:42:06
   * @Description: 文件上传
   */

  var logger$3 = utils.logger;
  var NATIVE_STATUS_CODE$3 = utils.NATIVE_STATUS_CODE;
  /**
   * 上传任务列表
   */

  var __UPLOAD_TASK_LIST__ = {};
  /**
   * 上传状态
   */

  var UploadState = {
    /**
     * 上传任务未开始
     */
    Undefined: -1001,

    /**
     * 枚举任务状态
     */
    All: -1,

    /**
     * 上传任务开始调度
     */
    Start: 0,

    /**
     * 上传任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 上传任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 上传任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 上传任务已完成（成功）
     */
    Finished: 4,

    /**
     * 上传任务已暂停
     */
    Pause: 5,

    /**
     * 上传任务发生异常
     */
    Error: 6
  };
  /**
   * 上传任务对象
   */

  var UploadTask = function (options) {
    /**
     * 上传任务TaskId
     */
    this.identify = utils.uuid('utask');
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 上传任务每次上传的文件块大小（仅在支持断点续传的服务有效）
     * 数值类型，单位为Byte（字节），默认值为102400，若设置值小于等于0则表示不分块上传
     */

    this.blocksize = this.options.blocksize || 0;
    /**
     * 分块上传的大小
     * 单位为Kb，设置值小于等于0则不分块上传，默认为不分块上传
     * Android平台需设置分块上传才能准确触发statechanged返回上传进度，
     * 如果不设置分块上传则在开始后快速返回上传完成进度，而实际并没有上传完。
     * 注意：分块上传需要服务器支持，如果服务器不支持则会删除失败。
     */

    this.chunkSize = this.options.blocksize || 0;
    /**
     * 网络请求类型
     * 仅支持http协议的“POST”
     */

    this.method = this.options.method || 'POST';
    /**
     * 上传任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是上传任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 上传任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 上传任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 上传任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.header = this.options.header || '';
    this.formData = '';
    /**
     * 上传任务完成后服务器返回的数据
     */

    this.responseText = '';
    /**
     * 已完成上传数据的大小
     */

    this.uploadedSize = 0;
    /**
     * 上传数据的总大小
     */

    this.totalSize = 0;
    /**
     * 上传任务当前状态
     */

    this.state = -1001;
    /**
     * 上传任务完成回调
     * @param {UploadTask} task 上传任务对象
     */

    this.completedCb = this.options.completedCb || function (task) {};
    /**
     * 上传任务状态变化时执行的回调
     * @param {UploadTask} task 上传任务对象
     */


    this.stateChangeCb = function (task) {};
  };
  /**
   * 上传任务结束时调用（任务完成、任务取消、清除）
   * @param {Object} UploadTask 上传任务对象
   * @param {Object} resonse {status,message} 返回对象
   */


  var deleteTask$1 = function (task) {
    delete __UPLOAD_TASK_LIST__[task.identify];
  };
  /**
   * 监听上传任务状态回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerCallback.call(task, options);
   */


  var handlerCallback$1 = function (options) {
    options = options || {};
    this.state = options.state || this.state;
    this.responseText = options.responseText || this.responseText;
    this.uploadedSize = options.uploadedSize || this.uploadedSize;
    this.totalSize = options.totalSize || this.totalSize;
    this.status = options.status;
    this.message = options.message;
    this.payload = options.payload; // identify
    // url
    // options
    // 上传任务状态变化回调函数，在上传任务状态发生变化时调用

    this.stateChangeCb(this); // 上传任务完成清除上传任务队列

    this.state == UploadState.Finished && deleteTask$1(this); // 上传任务完成、上传任务失败，都调用业务回调

    if (this.state == UploadState.Finished || this.state == UploadState.Error) {
      this.completedCb(this);
    }
  };
  /**
   * UploadState.Finished 上传任务完成，该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * UploadState.Error 上传任务发生异常，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var addStateChange$1 = function (task) {
    bridge$1.call('Uploader', 'stateChanged', {
      identify: task.identify
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$3.OK || status === NATIVE_STATUS_CODE$3.PROCESS) {
        handlerCallback$1.call(task, payload.upload);
      } else {
        deleteTask$1(task);
        logger$3.debug('====uploader-stateChanged====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };
  /**
   * 生成createUpload请求参数
   */


  var getUploadOptions = function (task) {
    return {
      url: task.url,
      options: {
        identify: task.identify,
        blocksize: task.blocksize,
        chunkSize: task.chunkSize,
        method: task.method,
        header: task.header,
        timeout: task.timeout,
        priority: task.priority,
        retry: task.retry,
        retryInterval: task.retryInterval
      }
    };
  };

  _extends(UploadTask.prototype, {
    /**
     * 添加上传文件
     * @param {String} path
     * @param {UploadFileOption} options
     * key: (String 类型 )文件键名
     * 上传文件在上传任务中的键名，默认值为为文件名称。
     * 上传任务中如果已经存在相同key的上传文件或数据将导致添加文件失败。
     * name: (String 类型 )文件名称
     * 上传文件的名称，默认值为上传文件路径中的名称。
     * mime: (String 类型 )文件类型
     * 上传文件的类型（如图片文件为“image/jpeg”），默认值自动根据文件后缀名称生成。可不传值
     * @param {Function} cb 回调
     */
    addFile: function (path, options, cb) {
      var _this = this;

      var data = {
        path: path,
        options: options,
        identify: _this.identify
      };
      bridge$1.call('Uploader', 'addFile', data, cb);
    },

    /**
     * 加上传数据
     * @param {String} key 键名
     * @param {String} value 值
     * @param {Function} cb 回调
     * @returns
     */
    addData: function (key, value, cb) {
      var _this = this;

      var data = {
        key: key,
        value: value,
        identify: _this.identify
      };
      bridge$1.call('Uploader', 'addData', data, cb);
    },

    /**
     * 开始上传任务
     */
    start: function () {
      var _this = this;

      bridge$1.call('Uploader', 'start', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停上传任务
     */
    pause: function () {
      var _this = this;

      bridge$1.call('Uploader', 'pause', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复上传任务
     */
    resume: function () {
      var _this = this;

      bridge$1.call('Uploader', 'resume', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 取消上传任务，
     */
    abort: function () {
      var _this = this;

      bridge$1.call('Uploader', 'abort', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
          deleteTask$1(_this);
        } else {
          logger$3.debug('====uploader-abort====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 上传任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    },

    /**
    * 开始所有上传任务
    */
    startAll: function () {
      bridge$1.call('Uploader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            addStateChange$1(task);
          });
        } else {
          logger$3.debug('====uploader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + JSON.stringify(payload));
        }
      });
    }
  });

  var uploader = {
    UploadState: UploadState,

    /**
     * 新建上传任务
     * @param {String} url 要上传文件资源地址
     * @param {Object} options 上传任务的参数，可选
     * @param {Function} completedCb 上传任务完成回调函数，回调参数为task
     */
    createUpload: function (url, options, completedCb) {
      if (typeof url != 'string') {
        return null;
      }

      options = options || {};
      options.url = url;
      options.completedCb = completedCb;
      var task = new UploadTask(options);
      __UPLOAD_TASK_LIST__[task.identify] = task;
      var data = getUploadOptions(task);
      bridge$1.call('Uploader', 'createUpload', data, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(task, payload.upload);
          addStateChange$1(task);
        } else {
          logger$3.debug('====uploader-createUpload====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
          deleteTask$1(task);
        }
      });
      return task;
    },

    /**
     * 开始所有上传任务
     */
    startAll: function () {
      bridge$1.call('Uploader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            addStateChange$1(task);
          });
        } else {
          logger$3.debug('====uploader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + JSON.stringify(payload));
        }
      });
    },

    /**
     * 清除上传任务
     * @param {UploadState} state 状态
     */
    clear: function (state) {
      state = state || this.UploadState.All;
      bridge$1.call('Uploader', 'clear', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            deleteTask$1(task);
          });
        } else {
          logger$3.debug('====uploader-clear====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 枚举上传任务
     * @param {UploadState} state 状态
     * @param {Function} cb 回调
     */
    enumerate: function (state, cb) {
      state = state || this.UploadState.All;
      bridge$1.call('Uploader', 'enumerate', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          var tasks = [];
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            tasks.push(task);
          });
          cb(tasks);
        } else {
          logger$3.debug('====uploader-enumerate====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-02 14:58:45
   * @Description: 设备信息
   */

  var device = {
    /**
     * @description 网络连接状态未知
     */
    CONNECTION_UNKNOW: 0,

    /**
     * @description 未连接网络
     */
    CONNECTION_NONE: 1,

    /**
     * @description 无线WIFI网络
     */
    CONNECTION_WIFI: 2,

    /**
     * @description GPRS
     */
    CONNECTION_GPRS: 3,

    /**
     * @description 蜂窝移动2G网络
     */
    CONNECTION_CELL2G: 5,

    /**
     * @description 蜂窝移动3G网络
     */
    CONNECTION_CELL3G: 6,

    /**
     * @description 蜂窝移动4G网络
     */
    CONNECTION_CELL4G: 7,

    /**
     * @description 获取系统版本信息
     * @returns {String} payload:{versionCode:xxx}
     */
    version: function (cb) {
      bridge$1.call('SystemInfo', 'getAppversion', {}, cb);
    },

    /**
     * @description 获取应用横竖屏状态
     * @type {Function}
     * @returns {Number} payload:{orientation:xxx}
     * { 0:未知; 1,2: 竖屏; 3, 4: 横屏 }
     */
    getOrientation: function (cb) {
      bridge$1.call('SystemInfo', 'getOrientation', {}, cb);
    },

    /**
     * @description 获取应用的安全区域信息
     * @type {Function}
     * @returns {Number} payload:{safeAreaInsets:xxx}
     * {"top":"","left":"","bottom":"","right":""}
     */
    getSafeAreaInsets: function (cb) {
      bridge$1.call('SystemInfo', 'getSafeAreaInsets', {}, cb);
    },

    /**
     * @description 获取应用的状态栏高度信息
     * @type {Function}
     * @returns {Float} payload:{statusbarHeight:xxx}
     */
    getStatusbarHeight: function (cb) {
      bridge$1.call('SystemInfo', 'getStatusbarHeight', {}, cb);
    },

    /**
     * @description 获取应用的状态栏样式信息
     * @type {Function}
     * @returns {String} payload:{style:xxx}
     * {default:黑色文字 ，light：白色文字 ，dark：（ios13支持暗黑模式）文字白色}
     */
    getStatusBarStyle: function (cb) {
      bridge$1.call('SystemInfo', 'getStatusBarStyle', {}, cb);
    },

    /**
     * @description 获取应用的状态栏样式信息
     * @type {Function}
     * @returns {Dictionary} payload:{xxx:xxx}
     *
     * name string 系统的名称 iOS| xxx
     *
     * osvendor string 系统的供应商信息
     *
     * version string 系统版本信息
     *
     * language string 语种
     *
     * height float 屏幕高度物理分辨率
     *
     * width float 屏幕宽度物理分辨率
     *
     * resolutionHeight float 屏幕高度逻辑分辨率
     *
     * resolutionWidth float 屏幕宽度逻辑分辨率
     *
     * scale float 逻辑分辨率与物理分辨率的缩放比例
     *
     * orientation int 获取应用横竖屏状态
     *
     * statusbarHeight float 状态栏高度
     *
     * safeAreaInsets Dictionary 应用的安全区域{"bottom" : 34,"top" : 44,"right" : 0,"left" : 0},
     *
     * vendor string 设备的生产厂商 iPhone Inc | xxx
     *
     * model string 设备的型号  iPhone | xxx
     *
     * innerVersion string 客户端FOX运行环境的内部版本号
     *
     * appid string 当前应用的APPID(bundleID)户
     *
     * appName string 客户端的应用名称
     *
     * versionCode string 客户端的版本号
     *
     * launcher string 应用启动来源
     *
     * arguments Dictionary 第三方程序调用时传递给程序的参数
     */
    getSystemInfo: function (cb) {
      bridge$1.call('SystemInfo', 'getSystemInfo', {}, cb);
    },

    /**
     * @description 获取应用的设备指纹-唯一标识信息
     * @type {Function}
     * @returns {String} payload:{uuid:xxx} 设备唯一标识别
     */
    getUUID: function (cb) {
      bridge$1.call('SystemInfo', 'getUUID', {}, cb);
    },

    /**
     * @description 获取应用的wifi开启状态
     * @type {Function}
     * @returns {String} payload:{wifiEnabled:boolean}
     * true/false
     */
    getWifiOpenStatus: function (cb) {
      bridge$1.call('SystemInfo', 'getWifiOpenStatus', {}, cb);
    },

    /**
     * @description 設備di
     * @type {Function}
     * @returns {String} payload:{wifiEnabled:boolean}
     * true/false
     */
    getDeviceId: function (cb) {
      bridge$1.call('SystemInfo', 'getDeviceId', {}, cb);
    },

    /**
     * @description 设置程序快捷方式图标上显示的角标数字
     * @type {Function}
     * @param {Object} data:{number: "5"} 设置程序快捷方式图标上显示的角标数字，android 仅支持小米，华为，部分支持oppo，vivo 
     * @returns void
     */
    setBadgeNumber: function (data, cb) {
      bridge$1.call('SystemInfo', 'setBadgeNumber', data, cb);
    },

    /**
     * @description 设置状态栏样式
     * @type {Function}
     * @param {String} stl 状态栏样式 [defaul：黑色字, light：白色字 ,dark：白色字(ios13支持)]
     * @returns void
     */
    setStatusBarStyle: function (stl, cb) {
      bridge$1.call('SystemInfo', 'setStatusBarStyle', stl, cb);
    },

    /**
     * @description 拨打电话
     * @type {Function}
     * @param {String} 电话号码
     * @returns void
     */
    dial: function (num, cb) {
      bridge$1.call('Application', 'dial', num, cb);
    },
    //获取底部高度
    getNavigationbarHeight: function getNavigationbarHeight(cb) {
      bridge$1.call('SystemInfo', 'getNavigationbarHeight', {}, cb);
    },

    /**
     * 结束app
     */
    appFinish: function (cb) {
      bridge$1.call('Application', 'appFinish', cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:16
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:40:49
   * @Description: 网络信息
   */

  var networkinfo = {
    /**
     * @description 网络连接状态未知
     */
    CONNECTION_UNKNOW: 0,

    /**
     * @description 未连接网络
     */
    CONNECTION_NONE: 1,

    /**
     * @description 无线WIFI网络
     */
    CONNECTION_WIFI: 2,

    /**
     * @description GPRS
     */
    CONNECTION_GPRS: 3,

    /**
     * @description 有线网络
     */
    CONNECTION_ETHERNET: 4,

    /**
     * @description 蜂窝移动2G网络
     */
    CONNECTION_CELL2G: 5,

    /**
     * @description 蜂窝移动3G网络
     */
    CONNECTION_CELL3G: 6,

    /**
     * @description 蜂窝移动4G网络
     */
    CONNECTION_CELL4G: 7,

    /**
     * @description 获取当前网络类型
     * @type {Function}
     * @returns {Number,String}  payload:{type:(Number)key,msg:(String)value}
     * {0:未知网络,1:无网络连接,2:wifi连接,3:GPRS连接,4:2.75G EDGE,5:2G,6:3G,7:4G,8:HRPD,9:3.5G HSDPA,10:3.5G HSUPA}
     */
    getCurrentType: function (cb) {
      bridge$1.call('SystemInfo', 'getCurrentType', {}, function (ret) {
        var networkType;
        var currentType = ret.payload.currentType.type;

        if (currentType === 0) {
          networkType = networkinfo.CONNECTION_UNKNOW;
        } else if (currentType === 1) {
          networkType = networkinfo.CONNECTION_NONE;
        } else if (currentType === 2) {
          networkType = networkinfo.CONNECTION_WIFI;
        } else if (currentType === 3) {
          networkType = networkinfo.CONNECTION_GPRS;
        } else if (currentType === 11) {
          networkType = networkinfo.CONNECTION_ETHERNET;
        } else if (currentType === 5) {
          networkType = networkinfo.CONNECTION_CELL2G;
        } else if (currentType === 6) {
          networkType = networkinfo.CONNECTION_CELL3G;
        } else if (currentType === 7) {
          networkType = networkinfo.CONNECTION_CELL4G;
        } else {
          networkType = 'other';
        }

        typeof cb === 'function' && cb({
          status: ret.status,
          message: ret.message,
          payload: {
            networkType: networkType
          }
        });
      });
    },

    /**
     * @description 获取IP地址信息
     * @type {Function}
     * @returns {String}  payload:{ipAddress:xxx}
     */
    getIpAddress: function (cb) {
      bridge$1.call('SystemInfo', 'getIpAddress', '', cb);
    }
    /**
     * @description 获取MAC地址信息
     * @type {Function}
     * @returns {String} payload:{macAddress:xxx}
     */
    // getMacAddress: cb => {
    //   core.call('SystemInfo', 'getMacAddress', {}, cb);
    // }

  };
  /*
   * @Author: helin3
   * @Date: 2020-01-16 10:00:23
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-16 16:04:19
   * @Description: 屏幕（亮度、截屏事件）
   */

  var logger$4 = utils.logger;
  var SdkError$2 = utils.SdkError;
  /**
   * 监听事件
   */

  var EventCallbacks = {};
  var KeyType = {
    UserCaptureScreen: 'UserCaptureScreen'
  };
  var screen = {
    /**
     * @description 设置屏幕亮度
     * @param {Number} value 屏幕亮度值，范围 0~1，0 最暗，1 最亮
     * @param {Function} cb 回调
     */
    setScreenBrightness: function (value, cb) {
      bridge$1.call('Screen', 'setBrightness', {
        value: value
      }, cb);
    },

    /**
     * @description 获取屏幕亮度
     * @param {Function} cb 回调
     * payload value 屏幕亮度值，范围 0~1，0 最暗，1 最亮
     */
    getScreenBrightness: function (cb) {
      bridge$1.call('Screen', 'getBrightness', '', cb);
    },

    /**
     * @description 设置是否保持常亮状态。仅在当前应用生效，离开应用后设置失效。
     * @param {Boolean} keepScreenOn 保持屏幕长亮
     * @param {Function} cb 回调
     */
    setKeepScreenOn: function (keepScreenOn, cb) {
      bridge$1.call('Screen', 'setWakelock', {
        keepScreenOn: keepScreenOn
      }, cb);
    },

    /**
     * 监听用户主动截屏事件，用户使用系统截屏按键截屏时触发此事件
     * @param {Function} cb 回调
     * @param {String} global 全局标识 0/true:为全局监听即所有webview都监听，1/false/默认:为当前webview监听
     */
    onUserCaptureScreen: function (cb, global) {
      if (global === void 0) global = '1';
      var event = KeyType.UserCaptureScreen;
      var evts = EventCallbacks[event] = EventCallbacks[event] || [];
      var flag = evts.some(function (item) {
        return item.fn === cb;
      });

      if (flag) {
        throw new SdkError$2('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge$1.call('Screen', 'onUserCaptureScreen', {
        eventName: event,
        global: global
      }, cb);
      EventCallbacks[event].push({
        cbid: cbid,
        fn: cb
      });
    },

    /**
     * 移除键盘监听事件
     * @param {Function} cb 移除监听的方法引用
     */
    offUserCaptureScreen: function (cb) {
      var event = KeyType.UserCaptureScreen;
      var evts = EventCallbacks[event] = EventCallbacks[event] || [];
      var someFlag = evts.some(function (item, index) {
        var flag = item.fn === cb;

        if (flag) {
          bridge$1.call('Screen', 'offUserCaptureScreen', {
            callbackid: item.cbid
          }, function () {}); // 移除事件监听时存储的业务回调对象

          evts.splice(index, 1); // 删除桥接层存储的监听回调方法

          bridge$1.removeCb(item.cbid);
        }

        return flag;
      });

      if (!someFlag) {
        logger$4.debug('当前方法引用未注册过监听或已被移除！');
      }
    },

    /**
     * 针对当前webview截屏
     * @param {object} 回调
     * @param {Function} cb 回调
     */
    capture: function (data, cb) {
      bridge$1.call('Application', 'capture', data, cb);
    },

    /**
     * IOS针对当前webview，截取已为手机端适配的web页面，截取纵向长图
     * @param {object} 回调
     * @param {Function} cb 回调
     */
    captureLongPic: function (data, cb) {
      bridge$1.call('Application', 'captureLongPic', data, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:16
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 19:09:28
   * @Description: 数据缓存
   */

  var storage = {
    /**
     * 根据Key值获取存储数据
     * @param {string} key key值
     * @param {Function} cb 回调
     */
    getItem: function (key, cb) {
      return bridge$1.call('Storage', 'getItem', key, function (res) {
        // 注：由于bridge在解析payload数据时，默认已做了一次字符串转JSON，故此处无需再次解析
        cb(res);
      });
    },

    /**
     * 设置Key/Value存储值
     * @param {string} key key值
     * @param {string} key value值
     * @param {Function} cb 回调
     */
    setItem: function (key, value, cb) {
      var data = {};
      data[key] = JSON.stringify(value);
      return bridge$1.call('Storage', 'setItem', data, cb);
    },

    /**
     * 删除指定Key值对应的键值对
     * @param {string} key key值
     * @param {Function} cb 回调
     */
    removeItem: function (key, cb) {
      return bridge$1.call('Storage', 'removeItem', key, cb);
    },

    /**
     * 清空存储
     * @param {Function} cb 回调
     */
    clear: function (cb) {
      return bridge$1.call('Storage', 'clear', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 19:32:46
   * @Description: 剪贴板
   */

  var clipboard = {
    /**
     * 设置系统剪贴板的内容
     * @param {String} data 数据
     * @param {Function} cb 回调
     * @returns
     */
    setData: function (data, cb) {
      bridge$1.call('PastBoard', 'setClipboardData', data, cb);
    },

    /**
     * 获取系统剪贴板内容。
     * @param {Function} cb 回调
     * @returns
     * {Object} payload {data}
     */
    getData: function (cb) {
      bridge$1.call('PastBoard', 'getClipboardData', '', cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:41:40
   * @Description: 应用运行环境
   */

  var runtime = {
    /**
     * @description 容器-文档在线查看
     * @type {Function}
     * @param {String} url  在线文档地址
     */
    openDoc: function (url, cb) {
      bridge$1.call('Application', 'openDocument', url, cb);
    },

    /**
     * @description 调用第三方程序打开指定的文件(ios可以直接打开)
     * @type {Function}
     * @param {String} url  离线文档地址
     */
    openFile: function (url, cb) {
      bridge$1.call('Application', 'openFile', url, cb);
    },

    /**
     * @description 调用第三方程序打开指定的URL，支持打开safari打开 网页，以及app
         * @type {Function}
     * @param {String} url 地址
     */
    openURL: function (url, cb) {
      bridge$1.call('Application', 'openURL', url, cb);
    },

    /**
     * @description 使用内置Webview窗口打开URL
     * @type {Function}
     * @param {String} url 地址
     */
    openWeb: function (url, cb) {
      bridge$1.call('Application', 'openWeb', url, cb);
    },

    /**
     * @description 获取应用启动来源，第三方程序调用时传递给程序的参数
     * @type {Function}
     */
    getLauncherPram: function (cb) {
      bridge$1.call('Application', 'getLauncherPram', {}, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-31 10:56:10
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:39:51
   * @Description: IO文件操作
   */

  var NATIVE_STATUS_CODE$4 = utils.NATIVE_STATUS_CODE;
  var extendClazz$1 = utils.extendClazz;
  /**
   * 文件系统定义（支持4种）
   * @param {String} name 文件系统名称
   * PRIVATE_WWW、PRIVATE_DOC
   * PUBLIC_DOCUMENTS、PUBLIC_DOWNLOADS
   * @param {Object} root {name, fullPath, remoteURL}
   */

  var FileSystem = function (name, root) {
    this.name = name || null;
    this.root = null;

    if (root) {
      var name$1 = root.name;
      var fullPath = root.fullPath;
      var remoteURL = root.remoteURL;
      this.root = new DirectoryEntry(name$1, fullPath, remoteURL, this);
    }
  };
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地文件或目录
   * @param {String} isFile
   * @param {String} isDirectory
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var Entry = function (isFile, isDirectory, name, fullPath, remoteURL, fileSystem) {
    /**
     * 文件操作对象的是否为文件，FileEntry对象固定其值为true
     */
    this.isFile = isFile;
    /**
     * 文件操作对象是否为目录，FileEntry对象固定其值为false
     */

    this.isDirectory = isDirectory;
    /**
     * 文件操作对象的名称，不包括路径
     */

    this.name = name || '';
    /**
     * 文件操作对象的完整路径，文件系统的绝对路径
     */

    this.fullPath = fullPath || '';
    /**
     * 文件远程URL地址，暂且值是扩展本地相对路径，如：_doc/xxx/xxx.doc
     */

    this.remoteURL = remoteURL || null;
    /**
     * 文件操作对象所属的文件系统对象，参考FileSystem
     */

    this.fileSystem = fileSystem || null;
  };
  /**
   * 定义文件操作对象基础方法
   */


  _extends(Entry.prototype, {
    /**
     * 获取目录/文件的属性
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 是否递归计算目录信息
     * @returns
     */
    getMetadata: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        srcTarget: this.fullPath,
        recursive: recursive
      };
      bridge$1.call('File', 'getMetadata', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 移动本地文件
     * @param {String} dest 目标文件绝对路径
     * @param {String} newName 文件名
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    moveTo: function (dest, newName, successCb, failCb) {
      var this$1 = this;
      var data = {
        srcPath: this.fullPath,
        destPath: dest,
        newName: newName
      };
      bridge$1.call('File', 'moveTo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem) : new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 复制本地文件
     * @param {String} dest 目标文件绝对路径
     * @param {String} newName 文件名
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    copyTo: function (dest, newName, successCb, failCb) {
      var this$1 = this;
      var data = {
        srcPath: this.fullPath,
        destPath: dest,
        newName: newName
      };
      bridge$1.call('File', 'copyTo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem) : new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 删除本地文件
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 递归删除，可选，默认false
     * @returns
     */
    remove: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        srcTarget: this.fullPath,
        recursive: recursive
      };
      bridge$1.call('File', 'remove', data, function (retObj) {
        var status = retObj.status;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(retObj);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 获取文件路径转换为本地路径URL地址
     */
    toLocalURL: function () {
      return 'file://' + this.fullPath;
    },

    /**
     * 获取目录路径转换为网络路径URL地址
     */
    toRemoteURL: function () {
      return this.remoteURL;
    }
  });
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地文件
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var FileEntry = function (name, fullPath, remoteURL, fileSystem) {
    Entry.call(this, true, false, name, fullPath, remoteURL, fileSystem);
  }; // FileEntry继承于Entry


  extendClazz$1(Entry, FileEntry);
  /**
   * 文件操作对象，基于文件上的特有方法
   */

  _extends(FileEntry.prototype, {
    /**
     * 获取文件摘要信息
     * @param {Function} cb 回调
     * @returns
     */
    getFileDigestInfo: function (digestAlgorithm, successCb, failCb) {
      if (digestAlgorithm === void 0) digestAlgorithm = 'md5';
      var data = {
        filePath: this.fullPath,
        digestAlgorithm: digestAlgorithm
      };
      bridge$1.call('File', 'getFileDigestInfo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  });
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地目录
   * @param {Boolean} isDirectory
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var DirectoryEntry = function (name, fullPath, remoteURL, fileSystem) {
    Entry.call(this, false, true, name, fullPath, remoteURL, fileSystem);
  }; // DirectoryEntry继承于Entry


  extendClazz$1(Entry, DirectoryEntry);
  /**
   * 目录操作对象，独有方法
   */

  _extends(DirectoryEntry.prototype, {
    /**
     * 获取目录的属性
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 是否递归查询,默认false
     * @returns
     */
    getFileListMetadata: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        filePath: this.fullPath,
        recursive: recursive
      };
      bridge$1.call('File', 'getFileListMetadata', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 创建或打开子目录
     * @param {String} path 要操作目录相对于当前目录的地址
     * @param {Object} flag {create: false, exclusive: false}
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    getDirectory: function (path, flag, successCb, failCb) {
      var this$1 = this;
      flag = _extends({
        create: false,
        exclusive: false
      }, flag || {});
      var data = {
        fullPath: this.fullPath,
        path: path,
        flag: flag
      };
      bridge$1.call('File', 'getDirectory', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 创建或打开文件
     * @param {String} path 要操作目录相对于当前目录的地址
     * @param {Object} flag {create: false, exclusive: false}
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    getFile: function (path, flag, successCb, failCb) {
      var this$1 = this;
      flag = _extends({
        create: false,
        exclusive: false
      }, flag || {});
      var data = {
        fullPath: this.fullPath,
        path: path,
        flag: flag
      };
      bridge$1.call('File', 'getFile', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  });

  var io = {
    /**
     * 应用运行资源目录常量
     */
    PRIVATE_WWW: 1,

    /**
     * 应用私有文档目录常量
     */
    PRIVATE_DOC: 2,

    /**
     * 程序公用文档目录常量
     */
    PUBLIC_DOCUMENTS: 3,

    /**
     * 程序公用下载目录常量
     */
    PUBLIC_DOWNLOADS: 4,

    /**
     * 将平台绝对路径转换成本地URL路径
     * @param {String} path 平台绝对路径，如：/var/xxx/doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 本地URL路径 _doc/xxx/xxx.txt
     */
    convertAbsoluteFileSystem: function (path, successCb, failCb) {
      bridge$1.call('File', 'convertAbsoluteFileSystem', path, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload.path);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 将本地URL路径转换成平台绝对路径
     * @param {String} path 本地URL路径，如：_doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 平台绝对路径 /var/xxx/doc/xxx/xxx.txt
     */
    convertLocalFileSystemURL: function (url, successCb, failCb) {
      bridge$1.call('File', 'convertLocalFileSystemURL', url, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload.path);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 快速获取指定的目录或文件操作对象，如通过URL值“_www/test.html”可直接获取文件
     * @param {String} url 要操作文件或目录的URL地址
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    resolveLocalFileSystemURL: function (url, successCb, failCb) {
      bridge$1.call('File', 'resolveLocalFileSystemURL', url, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var fsName = payload.fsName;
          var fsRoot = payload.fsRoot;
          var fs = new FileSystem(fsName, fsRoot);
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, fs) : new FileEntry(name, fullPath, remoteURL, fs);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 请求本地文件系统（返回绝对路径）
     *  PRIVATE_WWW:  _www/
     *  PRIVATE_DOC:  _doc/
     *  PUBLIC_DOCUMENTS:  _documents/
     *  PUBLIC_DOWNLOADS:  _downloads/
     * @param {Number} type 本地文件系统常量
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    requestFileSystem: function (type, successCb, failCb) {
      bridge$1.call('File', 'requestFileSystem', {
        type: type
      }, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var root = payload.root;
          var fs = new FileSystem(name, root);
          typeof successCb === 'function' && successCb(fs);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-31 10:56:10
   * @LastEditors  : helin3
   * @LastEditTime : 2019-12-31 14:38:16
   * @Description: 压缩/解压
   */

  var zip = {
    /**
     * 压缩生成Zip文件
     * @param {String} src 源文件路径或目录
     * @param {String} zipfile 压缩后保存的Zip文件路径
     * @param {Function} cb 回调
     * @returns
     */
    compress: function (src, zipfile, cb) {
      var data = {
        src: src,
        zipfile: zipfile
      };
      bridge$1.call('Zip', 'compress', data, cb);
    },

    /**
     * 解压缩Zip文件
     * @param {String} zipfile 要压缩的源文件路径，支持文件路径或目录
     * @param {String} target 压缩后保存的Zip文件路径
     * @param {Function} cb 回调
     * @returns
     */
    decompress: function (zipfile, target, cb) {
      var data = {
        target: target,
        zipfile: zipfile
      };
      bridge$1.call('Zip', 'decompress', data, cb);
    },

    /**
     * 图片压缩转换
     * @param {Object} options 参数
     * @param {Function} cb 回调
     * @returns
     */
    compressImage: function (options, cb) {
      bridge$1.call('Zip', 'compressImage', options, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:49:24
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:39:59
   * @Description: 系统软键盘
   */

  var SdkError$3 = utils.SdkError;
  /**
   * 监听键盘事件
   */

  var EventCallbacks$1 = {};
  var KeyType$1 = {
    KeyboardHeightChange: 'KeyboardHeightChange'
  };
  var key = {
    /**
     * 显示系统软键盘
     * @param {Function} cb 回调
     */
    showSoftKeybord: function (cb) {
      bridge$1.call('Keyboard', 'showSoftKeybord', '', cb);
    },

    /**
     * 隐藏系统软键盘
     * @param {Function} cb 回调
     */
    hideSoftKeybord: function (cb) {
      bridge$1.call('Keyboard', 'hideSoftKeybord', '', cb);
    },

    /**
     * 监听系统键盘事件
     * @param {String} event 事件名
     * @param {Function} cb 回调
     * @param {String} global 全局标识 0/true:为全局监听即所有webview都监听，1/false/默认:为当前webview监听
     */
    onKeyboardHeightChange: function (cb, global) {
      if (global === void 0) global = '1';
      var event = KeyType$1.KeyboardHeightChange;
      var evts = EventCallbacks$1[event] = EventCallbacks$1[event] || [];
      var flag = evts.some(function (item) {
        return item.fn === cb;
      });

      if (flag) {
        throw new SdkError$3('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge$1.call('Keyboard', 'onKeyboardHeightChange', {
        eventName: event,
        global: global
      }, cb);
      EventCallbacks$1[event].push({
        cbid: cbid,
        fn: cb
      });
    },

    /**
     * 移除键盘监听事件
     * @param {Function} cb 回调
     */
    offKeyboardHeightChange: function (cb) {
      var event = KeyType$1.KeyboardHeightChange;
      var evts = EventCallbacks$1[event] = EventCallbacks$1[event] || [];
      evts.some(function (item, index) {
        var flag = item.fn === cb;

        if (flag) {
          bridge$1.call('Keyboard', 'offKeyboardHeightChange', item.cbid || '', function () {}); // 移除事件监听时存储的业务回调对象

          evts.splice(index, 1); // 删除桥接层存储的监听回调方法

          bridge$1.removeCb(item.cbid);
        }

        return flag;
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 13:41:17
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 14:30:09
   * @Description: 密码键盘
   */

  var pwdkey = {
    MD5: 'md5',
    AES: 'aes',
    RSA: 'rsa',
    SM2: 'sm2',
    SM4: 'sm4',

    /**
     * 显示
     * @param {Object} data 请求参数
     * @param {Function} cb 回调
     */
    show: function (options, cb) {
      if (options === void 0) options = {};
      var data = {
        type: 'md5',
        number: false,
        confusion: 1,
        max: 100,
        closed: true,
        presses: true,
        input: '',
        encrypt: '',
        sm2Px: '',
        sm2Py: ''
      };

      _extends(data, options);

      bridge$1.call('PasswordKeyboard', 'show', data, cb);
    },

    /**
     * 隐藏密码键盘
     * @param {Object} data 请求参数
     * @param {Function} cb 回调
     * @returns {text, cipherText}
     */
    hide: function (cb) {
      bridge$1.call('PasswordKeyboard', 'hide', '', cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:38:49
   * @Description: 媒体 - 图片
   */

  var gallery = {
    /**
     * @description 图片预览
     * @type {Function}
     * @param {String} data
     * {"current":"1","urls":["图片路径1","图片路径2"],"indicator ":"default"}
     * current string 图片索引，默认显示第几张
     * urls  Array  请求参数字符串或键值对，可以是外网图片或者本地图片
     * indicator  String  图片指示器样式，可取值："default" - 底部圆点指示器； "number" - 顶部数字指示器； "none" - 不显示指示器。
     * longPressActions  Object   长按图片显示操作菜单，如不填默认为保存图片
     * @returns {Number}
     * {
     *    index       float   用户长按图片的索引值
     *    tapIndex  float  用户点击按钮列表的索引值
     * }
     */
    previewImage: function (data, cb) {
      bridge$1.call('Media', 'previewImage', data, cb);
    },

    /**
     * @description 预览图片 从系统相册选择文件（图片或视频）
     * @type {Function}
     * @param {String} data
     * {
     * "pickType":"2",// 1:单选 2:多选
     * "options":{
     *    "filter":"image", //文件类型 image:图片 video:视频 none:不过滤
     *    "maximum":"6"
     * }
     * @returns {String}
     * event  Array[String] 多选返回字段，为多路径的数组
     * file  string        单选返回字段，为文件路径
     */
    pick: function (url, cb) {
      bridge$1.call('Media', 'pick', url, cb);
    },

    /**
     * @description 保存图片到相册
     * @type {Function}
     * @param {String} url  图片路径
     */
    save: function (url, cb) {
      bridge$1.call('Media', 'save', url, cb);
    },

    /**
     * @description 图片裁剪
     * @type {Function}
     * @param {String} url  
     */
    pickSingleImageWithEdit: function (data, cb) {
      bridge$1.call('Media', 'pickSingleImageWithEdit', data, cb);
    },

    /**
     * @description 图片转Base64
     * @param {String} url  图片路径
     */
    imageBase64: function (url, cb) {
      bridge$1.call('Media', 'imageBase64', url, cb);
    },

    /**
     * @description 当前相册权限
     * @param {String} 
     */
    requestAuth: function (data, cb) {
      bridge$1.call('Media', 'requestAuth', data, cb);
    },

    /**
     * @description 打开更多权限页面
     * @param {String} 
     */
    openAuth: function (data, cb) {
      bridge$1.call('Media', 'openAuth', data, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:37:08
   * @Description: 媒体 - 相机
   */

  var camera = {
    /**
     * @description 拍照
     * @type {Function}
     * @param {String} options  
     * filename string 拍照或摄像文件保存的路径
     * format string	拍照或摄像的文件格式	 
     * index string	拍照或摄像头默认使用的摄像头	      Android-2.2+（不支持）
     * videoMaximumDuration string	视频长度	       Android-ALL（不支持）
     * optimize bool 是否优化图片	                    Ios-ALL（不支持
     * resolution bool 拍照或摄像分辨率	              Android-All（不支持）
     * popover bool 拍照或摄像界面弹出指示区域	        ios
     * @returns {String} payload : {capturedFile : ''}
     */
    captureImage: function (options, cb) {
      bridge$1.call('Media', 'captureImage', {
        'options': options
      }, cb);
    },

    /**
     * @description 拍照+水印（仅智能贷后项目）
     * @type {Function}
     * @param {String} options  
     * filename string 拍照或摄像文件保存的路径
     * format string	拍照或摄像的文件格式	 
     * index string	拍照或摄像头默认使用的摄像头	      Android-2.2+（不支持）
     * videoMaximumDuration string	视频长度	       Android-ALL（不支持）
     * optimize bool 是否优化图片	                    Ios-ALL（不支持
     * resolution bool 拍照或摄像分辨率	              Android-All（不支持）
     * popover bool 拍照或摄像界面弹出指示区域	        ios
     * @returns {String} payload : {capturedFile : ''}
     */
    captureImageWater: function (options, cb) {
      bridge$1.call('Media', 'captureImageWater', {
        "options": options
      }, cb);
    },

    /**
     * @description 获取摄像头管理对象
     * @type {Function}
     * @param {Object String} options  摄像头类型
     * {
     * "index":1,// 1:主摄像头  2:辅助摄像头
     * }  
     * @returns [Array Object] 
     * payload : {
     * supportedImageResolutions  字符串数组 摄像头支持的拍照分辨率
     * supportedVideoResolutions	字符串数组	摄像头支持的摄像分辨率
     * supportedImageFormats	    字符串数组	摄像头支持的拍照文件格式
     * supportedVideoFormats	    字符串数组	摄像头支持的摄像文件格式
     * }
     */
    getCamera: function (options, cb) {
      bridge$1.call('Media', 'getCamera', options, cb);
    },

    /**
    * @description 拍视频
    * @type {Function}
    * @param {Object} options  
    * filename string 拍照或摄像文件保存的路径
    * format string	拍照或摄像的文件格式	 
    * index string	拍照或摄像头默认使用的摄像头	      Android-2.2+（不支持）
    * videoMaximumDuration string	视频长度	       Android-ALL（不支持）
    * @returns {String} payload : {capturedFile : '视频位置相对路径'}
    */
    startVideoCapture: function (options, cb) {
      bridge$1.call('Media', 'startVideoCapture', options, cb);
    }
  };
  /*
   * @Author: Aleyn He
   * @Date: 2020-07-18 16:36:01
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 20:35:59
   * @Description: 音频录制及播放
   */

  var logger$5 = utils.logger;
  var NATIVE_STATUS_CODE$5 = utils.NATIVE_STATUS_CODE;
  /**
   * 音频录制状态
   */

  var RecorderState = {
    /**
     * 未开始
     */
    Wait: 0,

    /**
     * 录制中
     */
    Process: 1,

    /**
     * 暂停
     */
    Pause: 2,

    /**
     * 录制结束
     */
    Done: 3
  };
  /**
   * 录音录制对象
   */

  var AudioRecorder = function (options) {
    /**
     * 录制对象任务TaskId
     */
    this.taskId = utils.uuid('artask');
    this.options = options || {};
    /**
     * 录音文件保存目录，默认值：_doc/audio/<taskId>
     */

    this.saveDir = options.saveDir || '_doc/audio/' + this.taskId;
    /**
     * 录制最长时间限制，单位毫秒(ms); 0表示无限制；
     * 默认值：0
     */

    this.limitDuration = options.limitDuration || 0;
    /**
     * 录音分段时长，单位毫秒(ms)；默认值：600000（即10分钟）；
     */

    this.fragmentDuration = options.fragmentDuration || 1000 * 60 * 10;
    /**
     * 采样率，可选值：8000/16000/44100；默认值44100
     */

    this.sampleRate = options.sampleRate || 44100;
    /**
     * 编码码率，可选值，采样率/编码效率，8000（16000 ~ 48000）、16000（24000 ~ 96000）、44100（64000 ~ 320000）；
     * 默认值：64000
     */

    this.encodeBitRate = options.encodeBitRate || 64000;
    /**
     * 录音通道数，可选值：1/2；默认值2
     */

    this.numberOfChannels = options.numberOfChannels || 2;
    /**
     * 音频格式，有效值 wav
     */

    this.format = options.format || 'wav';
    /**
     * 所有录音分段信息
     */

    this.fragments = [];
    /**
     * 最新录制完成的分段信息
     */

    this.lastFragments = {};
    /**
     * 总大小：byte
     */

    this.totalSize = 0;
    /**
     * 总时长，ms
     */

    this.totalTime = 0;
    /**
     * 录制状态，0 未开始，1 录制中，2 录制结束
     */

    this.state = RecorderState.Wait;
    /**
     * 监听录制回调
     * @param {AudioRecorder} recorder 录制对象
     */

    this.onRecorderCb = function (recorder) {};
    /**
     * 录制业务回调
     */


    this.completedCb = options.completedCb || function () {};
  };
  /**
   * 根据录音录制对象，获取创建传输的参数
   * @param {*} recorder 
   */


  var getRecorderOptions = function (recorder) {
    return {
      taskId: recorder.taskId,
      saveDir: recorder.saveDir,
      limitDuration: recorder.limitDuration,
      fragmentDuration: recorder.fragmentDuration,
      sampleRate: recorder.sampleRate,
      encodeBitRate: recorder.encodeBitRate,
      numberOfChannels: recorder.numberOfChannels,
      format: recorder.format
    };
  };
  /**
   * 监听录制任务回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerRecorderCallback.call(recorder, options);
   */


  var handlerRecorderCallback = function (options) {
    this.totalTime = options.totalTime || this.totalTime;
    this.totalSize = options.totalSize || this.totalSize;
    this.state = options.state || this.state;
    this.fragments = options.fragments || this.fragments;
    this.lastFragments = options.completeFragment || this.lastFragments; // 录制任务回调

    this.onRecorderCb(this); // 录制结束调用业务回调

    if (this.state === RecorderState.Done) {
      this.completedCb(this);
    }
  };
  /**
   * 录制结束或者每录制完成一段即触发一次
   * RecorderState.Done 录制结束（主动/被动），该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * RecorderState.Process 录制完成一段，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var onRecorderListener = function (recorder) {
    bridge$1.call('AudioRecord', 'onRecordListener', {
      taskId: recorder.taskId
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$5.OK || status === NATIVE_STATUS_CODE$5.PROCESS) {
        handlerRecorderCallback.call(recorder, payload);
      } else {
        logger$5.debug('====AudioRecorder-onRecordListener====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };

  _extends(AudioRecorder.prototype, {
    /**
     * 开始音频录制
     */
    start: function () {
      var _this = this;

      bridge$1.call('AudioRecord', 'start', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioRecorder-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停音频录制
     */
    pause: function () {
      var _this = this;

      bridge$1.call('AudioRecord', 'pause', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioRecorder-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复音频录制
     */
    resume: function () {
      var _this = this;

      bridge$1.call('AudioRecord', 'resume', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioRecorder-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 结束音频录制
     */
    stop: function () {
      var _this = this;

      bridge$1.call('AudioRecord', 'stop', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioRecorder-stop====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  });
  /**
   * 音频播放状态
   */


  var PlayerState = {
    /**
     * 未开始
     */
    Wait: 0,

    /**
     * 播放中
     */
    Process: 1,

    /**
     * 暂停
     */
    Pause: 2,

    /**
     * 播放结束
     */
    Done: 3
  };
  /**
   * 录音播放对象
   */

  var AudioPlayer = function (options) {
    /**
       * 录音播放任务TaskId
       */
    this.taskId = utils.uuid('aptask');
    this.options = options || {};
    /**
     * 音频分段路径；按照顺序播放；
     * 示例：["_doc/audio/1233434.wav", "_doc/audio/123we4.wav", "_doc/audio/12trtrt4.wav"]
     * 目前仅支持格式：pcm/wav
     */

    this.fragments = options.fragments || [];
    /**
     * 播放类型，有效值：Phone/Speaker（听筒/扬声器）
     * 默认值：Phone（听筒）
     */

    this.mode = options.mode || 'Phone';
    /**
     * 播放进度回调时间间隔，单位ms，默认1000ms；
     */

    this.duration = options.duration || 1000;
    /**
     * 当前播放位置
     */

    this.seek = 0;
    /**
     * 总大小：byte
     */

    this.totalSize = 0;
    /**
     * 总时长，ms
     */

    this.totalTime = 0;
    /**
     * 播放状态，0 未开始/暂停，1 播放中，2 播放结束
     */

    this.state = PlayerState.Wait;
    /**
     * 监听播放回调
     * @param {AudioPlayer} player 录制对象
     */

    this.onPlayerCb = function (player) {};
    /**
     * 播放完成业务回调
     */


    this.completedCb = options.completedCb || function () {};
  };
  /**
   * 监听播放任务回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerPlayerCallback.call(recorder, options);
   */


  var handlerPlayerCallback = function (options) {
    this.totalTime = options.totalTime || this.totalTime;
    this.totalSize = options.totalSize || this.totalSize;
    this.seek = options.seek || this.seek;
    this.state = options.state || this.state; // 播放任务回调

    this.onPlayerCb(this); // 录制结束调用业务回调

    if (this.state === PlayerState.Done) {
      this.completedCb(this);
    }
  };
  /**
   * 播放进度监听
   * @param {*}} player 音频播放对象
   */


  var onPlayerProgress = function (player) {
    bridge$1.call('AudioPlay', 'onProgress', {
      taskId: player.taskId,
      duration: player.duration
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$5.OK || status === NATIVE_STATUS_CODE$5.PROCESS) {
        handlerPlayerCallback.call(player, payload);
      } else {
        logger$5.debug('====AudioPlayer-onProgress====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };

  _extends(AudioPlayer.prototype, {
    /**
     * 开始音频播放
     */
    start: function () {
      var _this = this;

      bridge$1.call('AudioPlay', 'start', {
        taskId: _this.taskId,
        mode: _this.mode
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioPlayer-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停音频播放
     */
    pause: function () {
      var _this = this;

      bridge$1.call('AudioPlay', 'pause', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioPlayer-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复音频播放
     */
    resume: function () {
      var _this = this;

      bridge$1.call('AudioPlay', 'resume', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioPlayer-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 结束音频播放
     */
    stop: function () {
      var _this = this;

      bridge$1.call('AudioPlay', 'stop', {
        taskId: _this.taskId
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioPlayer-stop====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 指定音频播放位置
     * @param {*} position 播放位置（ms），默认：0
     */
    seekTo: function (position) {
      if (position === void 0) position = 0;

      var _this = this;

      bridge$1.call('AudioPlay', 'seekTo', {
        taskId: _this.taskId,
        position: position
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status !== NATIVE_STATUS_CODE$5.OK) {
          logger$5.debug('====AudioPlayer-seekTo====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  });

  var audio = {
    /**
     * 音频录制状态
     */
    RecorderState: RecorderState,

    /**
     * 音频播放状态
     */
    PlayerState: PlayerState,

    /**
     * 获取当前设备的录音对象
     * @param {*} options 音频录制参数
     * @param {*} successCb 音频录制成功/失败结束
     * @param {*} errorCb 创建音频录制失败回调
     */
    createRecorder: function (options, successCb, errorCb) {
      options = options || {};
      options.completedCb = successCb;
      var recorder = new AudioRecorder(options);
      var data = getRecorderOptions(recorder);
      bridge$1.call('AudioRecord', 'create', data, function (retObj) {
        var status = retObj.status;

        if (status === NATIVE_STATUS_CODE$5.OK) {
          onRecorderListener(recorder);
        } else {
          typeof errorCb === 'function' ? errorCb(retObj) : void 0;
        }
      });
      return recorder;
    },

    /**
     * 根据录音任务Id获取录音信息
     * @param {*} taskId 录音任务Id
     * @param {*} cb 回调函数
     */
    getAudioInfo: function (taskId, cb) {
      bridge$1.call('AudioRecord', 'getAudioInfo', {
        taskId: taskId
      }, cb);
    },

    /**
     * 创建音频播放
     * @param {*} options 音频播放参数
     * @param {*} successCb 音频播放结束回调
     * @param {*} errorCb 创建音频播放失败回调
     */
    createPlayer: function (options, successCb, errorCb) {
      options = options || {};
      options.completedCb = successCb;
      var player = new AudioPlayer(options);
      var data = {
        taskId: player.taskId,
        fragments: player.fragments
      };
      bridge$1.call('AudioPlay', 'create', data, function (retObj) {
        var status = retObj.status;

        if (status === NATIVE_STATUS_CODE$5.OK) {
          onPlayerProgress(player);
        } else {
          typeof errorCb === 'function' ? errorCb(retObj) : void 0;
        }
      });
      return player;
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-02 11:29:39
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-02 17:13:58
   * @Description: 通讯录
   */

  var contacts = {
    /**
     * @param {Function} cb 回调
     * @returns payload
     * [{id,name,displayName,nickname,iphoneNum}]
     */
    getAddressBook: function (cb) {
      bridge$1.call('Contacts', 'getAddressBook', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:25:42
   * @LastEditors  : helin3
   * @LastEditTime : 2019-12-30 21:11:09
   * @Description: Webview
   */

  var SdkError$4 = utils.SdkError;
  var WebviewEvents = {};
  /**
   * 转场类型
   */

  var AnimationType = {
    Fade: '1',
    // 淡入淡出
    Push: '2',
    // 推进效果
    Reveal: '3',
    // 揭开效果
    MoveIn: '4' // 慢慢进入并覆盖效果

  };
  var webview = {
    AnimationType: AnimationType,

    /**
     * 创建并显示 Webview
     * @param {Object} data {
     * url: (String)webview地址,
     * id_wvobj: (String)webviewid,
     * style: {width: (Number)宽度, height: (Number)高度}
     * @param {Function} cb 回调
     * }
     */
    open: function (data, cb) {
      bridge$1.call('Webview', 'create', data, function () {
        bridge$1.call('Webview', 'show', {
          id_wvobj: data.id_wvobj
        }, cb);
      });
    },

    /**
     * 创建 Webview
     * @param {Object} data {
     * url: (String)webview地址,
     * id_wvobj: (String)webviewid,
     * style: {width: (Number)宽度, height: (Number)高度}
     * @param {Function} cb 回调
     */
    create: function (data, cb) {
      bridge$1.call('Webview', 'create', data, cb);
    },

    /**
     * 显示 Webview
     * @param {String} id_wvobj id
     * @param {Function} cb 回调
     */
    show: function (wvid, cb) {
      bridge$1.call('Webview', 'show', {
        id_wvobj: wvid
      }, cb);
    },

    /**
     * push新的webview
     * @param {Object} data {url: String访问地址, animation: AnimationType转场类型}
     * @param {Function} cb 回调
     */
    pushNewWeb: function (data, cb) {
      bridge$1.call('Webview', 'pushNewWeb', data, cb);
    },

    /**
     * 关闭webview
     * @param {String} wvid webview id
     * @param {Function} cb 回调
     */
    close: function (wvid, cb) {
      bridge$1.call('Webview', 'close', {
        id_wvobj: wvid
      }, cb);
    },

    /**
     * 重新加载页面
     * @param {Function} cb 回调
     */
    reload: function (cb) {
      bridge$1.call('Webview', 'reload', {}, cb);
    },

    /**
     * 获取所有webviewid
     * @param {Function} cb 回调
     */
    all: function (cb) {
      bridge$1.call('Webview', 'all', {}, cb);
    },

    /**
     * 关闭当前webview
     */
    closeSelf: function (cb) {
      bridge$1.call('Webview', 'closeSelf', {}, cb);
    },

    /**
     * 获取当前js执行的webview对象
     */
    currentWebview: function (cb) {
      bridge$1.call('Webview', 'currentWebview', {}, cb);
    },

    /**
     * 获取webviewId获取webview对象
     */
    getWebviewById: function (id_wvobj, cb) {
      bridge$1.call('Webview', 'getWebviewById', id_wvobj, cb);
    },

    /**
     * 监听全局的自定义事件。事件可以由foxsdk.webview.emit触发，回调函数会接收所有传入事件触发函数的额外参数。
     */
    on: function (eventName, cb) {
      if (!eventName || typeof cb !== 'function') {
        bridge$1.call('Webview', 'on', '', cb);
        return;
      }

      var events = WebviewEvents[eventName] = WebviewEvents[eventName] || [];
      var flag = events.some(function (it) {
        return it.fn === cb;
      });

      if (flag) {
        throw new SdkError$4('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge$1.call('Webview', 'on', eventName, cb);
      events.push({
        cbid: cbid,
        fn: cb
      });
    },

    /**
     * 触发全局的自定事件。附加参数都会传给监听器回调。
     */
    emit: function (eventName, data, cb) {
      var mdata = {
        eventName: eventName,
        data: data
      };
      bridge$1.call('Webview', 'emit', mdata, cb);
    },

    /**
     * 触发全局的自定事件。附加参数都会传给监听器回调。
     */
    off: function (eventName, cb) {
      console.log(WebviewEvents[eventName]);

      if (eventName && cb) {
        //事件名和回调都有，则两者要一致才移除
        if (typeof cb != 'function') {
          throw new SdkError$4('11007', 'cb不是个方法类型');
        } //移除事件名无论是否注册，都会返回 0成功


        if (!WebviewEvents[eventName]) {
          bridge$1.call('Webview', 'off', {
            eventName: eventName
          }, cb);
          return;
        }

        var evts = WebviewEvents[eventName];
        var index = evts.findIndex(function (obj) {
          return obj.fn === cb;
        });

        if (index == -1) {
          cb({
            'status': '11007',
            message: 'failed',
            data: '移除监听失败,事件名和回调不一致'
          });
          return; // throw new SdkError('11007', '移除监听失败,事件名和回调不一致');
        }

        console.log("target before =", target);
        var target = evts.splice(index, 1);
        var callbackid = target[0]['cbid'];
        console.log("target=", target);
        console.log('callbackId=', callbackid);
        bridge$1.removeCb(callbackid);
        var data = {
          eventName: eventName,
          callbackid: callbackid
        };
        bridge$1.call('Webview', 'off', data, cb);
      } else if (eventName) {
        //如果只提供了事件名，则移除该事件所有的监听器
        if (WebviewEvents[eventName]) {
          var evts$1 = WebviewEvents[eventName];
          evts$1.some(function (item, index) {
            var callbackid = item['cbid']; // console.log("item=", item);

            console.log('remove callbackId=', callbackid);
            bridge$1.removeCb(callbackid);
          });
          evts$1 = [];
        }

        var data$1 = {
          eventName: eventName
        };
        bridge$1.call('Webview', 'off', data$1, function (ret) {
          console.log(JSON.stringify(ret));
        });
      } else if (!eventName && cb) {
        bridge$1.call('Webview', 'off', {}, cb);
      }
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:57:03
   * @LastEditors  : helin3
   * @LastEditTime : 2020-02-13 10:55:54
   * @Description: 描述信息
   */

  var touchid = {
    /**
     * @description 验证指纹
     * @param {Function} cb 回调
     * @returns payload: {code: '', msg: ''}
     * 枚举值:
     * 0 指纹认证通过
     * 55001 指纹信息变更
     * 55002 设备不支持指纹识别
     * 55003 系统取消授权
     * 55004 用户取消验证Touch ID
     * 55005 授权失败
     * 55006 系统未设置密码
     * 55007 设备Touch ID不可用
     * 55008 TouchID未注册
     * 55009 用户选择输入密码
     * 55010 其他情况
     */
    fingerPrintVerification: function (cb) {
      bridge$1.call('TouchId', 'fingerPrintVerification', '', cb);
    },

    /**
     * @description 获取设备支持的生物识别类型
     * @param {Function} cb 回调
     * @returns payload: {biometricsType: '', biometricsText: ''}
     * biometricsType: 0 不支持touchid和faceid等生物识别；1 支持touchid；2 支持faceid
     */
    deviceBiometrics: function (cb) {
      bridge$1.call('TouchId', 'deviceBiometrics', '', cb);
    },

    /**
     * @description 是否支持指纹识别(已废弃)
     * @param {Function} cb
     * @returns {Boolean} hasFingerPrint {0:支持,1:不支持}
     */
    // hasFingerPrint: cb => {
    //   bridge.call('TouchId', 'hasFingerPrint', '', cb);
    // },

    /**
     * @description 更新变更后的指纹信息，前端其他安全方式验证后调用此方法
     * @param {Function} cb
     * @returns {Boolean} updateTouchIdResult
     */
    updateTouchId: function (cb) {
      bridge$1.call('TouchId', 'updateTouchId', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-03 10:06:54
   * @Description: 二维码
   */

  var barcode = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    scan: function (cb) {
      bridge$1.call('BarCode', 'scan', '', cb);
    },

    /**
     * 根据文字，生成二维码图片
     */
    createQRCodeImage: function (data, cb) {
      bridge$1.call('BarCode', 'createQRCodeImage', data, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-28 09:34:27
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:40:14
   * @Description: 位置
   * TODO: 后续可考虑将位置信息缓存起来
   */
  // 监听事件ID

  var __WATCH_IDS__ = {};
  var location = {
    /**
     * 获取位置信息
     * @param {Function} cb 回调
     * @param {Object} option
     *   {String} enableHighAccuracy 是否高精确度获取位置信息默认是"1"，高精确度获取位置信息。字符串"0":不获取高精度。字符串"1":获取高精度值
     *   {Number} timeout 获取位置信息的超时时间,单位（秒）默认值30
     *   {Number} maximumAge 获取位置信息的间隔时间,单位（秒）默认30
     *   {String} coordsType 坐标系'GCJ-02（字段已废弃，默认返回GCJ-02）
     *   {String} geocode 是否解析地址信息 "1":返回地理位置信息+经纬度"0":只返回经纬度，默认"0"
     * @returns payload
     * coords
     *   {Long} longitude 经度
     *   {Long} latitude 维度
     * coordsType
     * address
     */
    getCurrentPosition: function (cb, option) {
      var data = {
        enableHighAccuracy: '1',
        timeout: 30,
        maximumAge: 30,
        // coordsType: 'GCJ-02',//'WGS-84',
        geocode: '0'
      };

      _extends(data, option);

      return bridge$1.call('Location', 'getCurrentPosition', data, cb);
    },

    /**
     * 监听设备位置变化信息
     * @param {Function} cb 回调
     * @param {Object} option
     *   {String} enableHighAccuracy 是否高精确度获取位置信息  默认是"1"，高精确度获取位置信息。字符串"0":不获取高精度。字符串"1":获取高精度值
     *   {Number} timeout 获取位置信息的超时时间,单位（秒）默认值30
     *   {Number} maximumAge 获取位置信息的间隔时间,单位（秒）默认30
     *   {String} coordsType 坐标系 GCJ-02（已废弃，直接返回GCJ-02坐标系）
     *   {String} geocode 是否解析地址信息"1":返回地理位置信息+经纬度 "0":只返回经纬度，默认"0"
     * @returns
     */
    watchPosition: function (cb, option) {
      var data = {
        enableHighAccuracy: "1",
        timeout: 30,
        maximumAge: 30,
        // coordsType: 'GCJ-02',//'WGS-84',
        geocode: "0"
      };

      _extends(data, option);

      var watchId = utils.uuid('timer');
      data.eventName = 'locationDidChanged';
      data.watchId = watchId;
      __WATCH_IDS__[watchId] = {
        cbid: bridge$1.call('Location', 'watchPosition', data, cb)
      };
      return watchId;
    },

    /**
     * 关闭指定监听设备位置信息
     * @param {string} watchId 需要取消的位置监听器标识，调用watchPosition方法的返回值
     * @param {Function} cb 回调
     * @return
     */
    clearWatch: function (watchId, cb) {
      if (!__WATCH_IDS__[watchId].cbid) {
        return;
      }

      var data = {
        watchId: watchId,
        callbackid: __WATCH_IDS__[watchId].cbid
      };
      bridge$1.call('Location', 'clearWatch', data, function (ret) {
        if (ret.status === utils.NATIVE_STATUS_CODE.OK) {
          // 移除原生事件监听对应的回调方法
          bridge$1.removeCb(__WATCH_IDS__[watchId].cbid);
        }

        cb(ret);
      });
    },

    /**
     * 打开地图，可以选择商户
     * data{shopName ,shopAddress,longitude,latitude}
     */
    openMap: function (data, cb) {
      bridge$1.call('Location', 'openMap', data, cb);
    },

    /**
     * 关闭所有监听设备位置信息
     * @param {Function} cb 回调
     */
    clearWatchAll: function (cb) {
      bridge$1.call('Location', 'clearWatchAll', '', function (ret) {
        if (ret.status === utils.NATIVE_STATUS_CODE.OK) {
          Object.keys(__WATCH_IDS__).forEach(function (watchId) {
            // 移除原生事件监听对应的回调方法
            bridge$1.removeCb(__WATCH_IDS__[watchId].cbid);
            delete __WATCH_IDS__[watchId];
          });
        }

        cb(ret);
      });
    },

    /**
      * 打开地图导航，可以选择商户的地址
      * data{"address: ":"天府三街","longitude":30.231313,"latitude":123.0231}
      */
    navigate: function (data, cb) {
      bridge$1.call('Location', 'navigate', data, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-14 21:49:25
   * @Description: 第三方服务 - 分享
   */

  var SHARE_CHANNALS = {
    'webchat': '1',
    'timeline': '2',
    'sina': '10',
    'dingtalk': '20',
    'line': '50',
    'facebook': '30',
    'whatsapp': '40',
    'instagram': '70',
    'telegram': '60'
  };
  var SHARE_TYPE = {
    'web': '0',
    'text': '1',
    'image': '2',
    'href': '3',
    'application': '4',
    'music': '5',
    'video': '6',
    'file': '7'
  };
  var share = {
    /**
     * @description 获取分享服务
     * @type {Function}
     * @param {String} options  使用sdk平台(目前只支持Mod)
     * @returns {Object Array}
     * channels:[{channel:'',name:''}]
     */
    getShareServices: function (options, cb) {
      bridge$1.call('Share', 'getShareServices', options, cb);
    },

    /**
     * @description 微信分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByWechat: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge$1.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 朋友圈分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByMoments: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge$1.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 新浪微博分享
     * @type {Function}
     * @param {Object String} options
     */
    sendBySina: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge$1.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 钉钉分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByDingTalk: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge$1.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 钉钉分享
     * @type {Function}
     * @param {Object String} options
     */
    sendwithsystem: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge$1.call('Share', 'sendWithSystem', options, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:41:18
   * @Description: 第三方服务 - 推送
   */

  var push = {
    /**
     * @description 监听推送事件(已废弃)
     * @type {Function}
     * @param {String} options  事件参数
     * "click"  - 从系统消息中心点击消息启动应用事件
     * "receive"- 应用从推送服务器接收到推送消息事件
     */
    addEventListener: function (eventName, cb, isGlobel) {
      var options = {
        isGlobel: isGlobel || false,
        eventName: eventName
      };
      bridge$1.call('EventListener', 'addEventListener', options, cb);
    },

    /**
     * @description 清除通知中心的消息
     * @type {Function}
     */
    clear: function (cb) {
      bridge$1.call('Push', 'clear', '', cb);
    },

    /**
     * @description 创建本地消息
     * @type {Function}
     * @param {Object String} options
     * {
     *    content : String,
     *    payload : String,//消息承载的数据
     *    notificationId: String,//消息ID
     *    options : {
     *      cover : boolean,//默认false
     *      delay : long,//延迟显示秒数
     *      icon  : string,//消息图标
     *      sound : string,//推送消息音 默认 system
     *      title : string,//标题
     *      subtitle : string,//子标题
     *      when  : long //ios不支持，安卓支持显示推送时间
     *    }
     * }
     */
    createMessage: function (options, cb) {
      bridge$1.call('Push', 'createMessage', options, cb);
    },

    /**
     * @description 获取所有消息
     * @type {Function}
     * @returns [Array Object] 获取客户端接收到的所有本地消息
     */
    getAllMessage: function (cb) {
      bridge$1.call('Push', 'getAllMessage', {}, cb);
    },

    /**
     * @description 删除指定消息
     * @type {Function}
     * @param {String} msgId 消息ID
     */
    remove: function (msgId, cb) {
      bridge$1.call('Push', 'remove', msgId, cb);
    },

    /**
     * @description 获取客户端推送标识信息
     * @type {Function}
     * @returns {Object} payload:
     * {
     * clientInfo:
     *  {
     *    id String 推送通道标识
     *    token String 设备令牌（iOS设备唯一标识），用于APNS服务推送中标识设备的身份
     *    clientid String 设备唯一标识
     *    appid String 第三方推送服务的应用标识
     *    appkey String 第三方推送服务器的应用键值
     *   }
     * }
     */
    getClientInfo: function (cb) {
      bridge$1.call('Push', 'getClientInfo', '', cb);
    },

    /**
     * @description 设置程序是否将消息显示在系统消息中心
     * @type {Function}
     * @param {Object String} isNotify 是否通知  
     */
    setAutoNotification: function (isNotify, cb) {
      bridge$1.call('Push', 'setAutoNotification', {
        "notify": isNotify
      }, cb);
    },

    /**
       * @description 设置推送tag
       * @type {Function}
       */
    setAlias: function (alias, cb) {
      bridge$1.call('Push', 'setAlias', alias, cb);
    },

    /**
     * @description 删除推送tag
     * @type {Function}
     */
    deleteAlias: function (cb) {
      bridge$1.call('Push', 'deleteAlias', {}, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:23:01
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:41:11
   * @Description: OCR识别
   */

  var RecognizeType = {
    /**
     * 通用文字识别
     */
    Text: '0',

    /**
     * 身份证识别
     */
    IDCard: '1',

    /**
     * 身份证正面识别
     */
    IdCardFront: '2',

    /**
     * 身份证背面识别
     */
    IdCardBack: '3',

    /**
     * 银行卡识别
     */
    BankCard: '4',

    /**
     * 网络图片识别
     */
    WebImage: '5',

    /**
     * 驾驶证证识别
     */
    DrivingLicense: '6',

    /**
     * 行驶证识别
     */
    VehicleLicense: '7',

    /**
     * 车牌识别
     */
    PlateNumber: '8',

    /**
     * 营业执照识别
     */
    BusinessLicens: '9',

    /**
     * 票据识别
     */
    Receipt: '10',

    /**
     * iOCR识别
     */
    IOCRRecognition: '11'
  };
  var ocr = {
    /**
     * OCR识别类型
     */
    RecognizeType: RecognizeType,

    /**
     * @param {String} recognizeType OCR识别类型
     * @param {String} needBase64 "1"表示需要返回base64编码，其他不返回,默认0
     * @param {Function} cb 回调
     * @returns
     * {Object} payload
     */
    startOCR: function (recognizeType, cb, needBase64) {
      if (needBase64 === void 0) needBase64 = '0';
      bridge$1.call('OCR', 'startOCR', {
        recognizeType: recognizeType,
        needBase64: needBase64
      }, cb);
    },

    /**
     * 获取OCR支持的服务
     * @param {Object} sdkType 默认值: Baidu
     * @param {Function} cb 回调
     * @returns {Object} retObject
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据 {
     *  ocrSupports: [
     *  0-'通用文字识别',
     *  1-'身份证识别',
     *  2-'身份证正面识别',
     *  3-'身份证背面识别',
     *  4-'银行卡识别',
     *  5-'网络图片识别',
     *  6-'驾驶证证识别',
     *  7-'行驶证识别',
     *  8-'车牌识别',
     *  9-'营业执照识别',
     *  10-'票据识别',
     *  11-'iOCR识别'
     * ]
     * }
     */
    getOCRServices: function (sdkType, cb) {
      sdkType = sdkType || 'Baidu';
      bridge$1.call('OCR', 'getOCRServices', {
        sdkType: sdkType
      }, cb);
    }
  };
  /**
   * @created by helin3 2019-12-30
   * @updated by
   * @description Face 人脸识别/活体检测
   */

  var face = {
    /**
     * 人脸识别/活体检测
     * @param {Object} data 请求参数
     * {
     *   {String} livenessType ['meglive': 动作活体; 'still': 静默活体; 'flash': 炫彩活体]
     *   {String} username 姓名
     *   {String} idcard 身份证号
     * }
     * @param {Function} cb 回调
     * @returns
     */
    face: function (data, cb) {
      bridge$1.call('Face', 'face', data, cb);
    },

    /**
     * 二代证识别
     * @param {Object} data
     * *{String} ScreenOrientation 0：竖屏 1：横屏
     * *{String} IDCardShootPage 0：身份证人像；1：国徽面
     * @param {Function} cb 回调
     * @returns
     */
    idcard: function (data, cb) {
      bridge$1.call('Face', 'idcard', data, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2020-01-06 14:19:20
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:38:28
   * @Description: 客户端事件
   * TODO: 关于全局事件监听，还存在缺陷，同时要评估globalCbId=>__FOX_EVENT_CALLBACKS__影响，以及是否有必要存在
   */

  var SdkError$5 = utils.SdkError;
  var KeyEvent = {
    background: [],
    // 切换到后台
    foreground: [],
    // 切换到前台
    backbutton: [],
    // 物理键返回
    netchange: [],
    // 网络状态变化
    locationDidChanged: [],
    //位置信息变化监听
    pushMessage: [],
    // 收到推送
    KeyboardHeightChange: [] //系统键盘高度变化

  };
  var events = {
    /**
     * @description 绑定监听事件
     * @type {Function}
     * @param {String} eventName  事件名
     * @param {Function} cb  回调函数
     * @param {String} global 全局标识：
     * 0/true:注册时的webview不管是否在栈顶可见，都能在消息发生时收到消息通知，
     * 1/false/默认:注册为当前webView在栈顶且可见时，消息发生能收到通知
     */
    addEventListener: function (eventName, cb, global) {
      if (global === void 0) global = 1;

      if (!eventName || typeof cb !== 'function') {
        return;
      }

      if (!KeyEvent[eventName]) {
        throw new SdkError$5('69001', '不支持的事件类型');
      }

      global = global === 0 || global === true ? '0' : '1';
      var evts = KeyEvent[eventName];
      var flag = evts.some(function (it) {
        return it.fn === cb;
      });

      if (flag) {
        throw new SdkError$5('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge$1.call('EventListener', 'addEventListener', {
        eventName: eventName,
        isGlobal: global
      }, cb);
      evts.push({
        cbid: cbid,
        fn: cb
      });

      if (global === '0') {
        window.__FOX_EVENT_CALLBACKS__[cbid] = cbid;
      }
    },

    /**
     * @description 移除监听事件
     * @type {Function}
     * @param {String} eventName  事件名
     * @param {Function} cb  回调函数
     * @param {String} global 全局标识:
     *  0/true:注册时的webview不管是否在栈顶可见，都能在消息发生时收到消息通知，
     *  1/false/默认:注册为当前webView在栈顶且可见时，消息发生能收到通知
     */
    removeEventListener: function (eventName, cb, global) {
      if (global === void 0) global = 1;

      if (!eventName || typeof cb != 'function') {
        return;
      }

      if (!KeyEvent[eventName]) {
        throw new SdkError$5('69001', '不支持的事件类型');
      }

      global = global === 0 || global === true ? '0' : '1';
      var evts = KeyEvent[eventName]; // 目前不支持批量移除事件

      var index = evts.findIndex(function (obj) {
        return obj.fn === cb;
      });

      if (index > -1) {
        // 从事件数组中删除该事件监听
        var target = evts.splice(index, 1);
        var callbackid = target[0]['callbackid'];
        bridge$1.call('EventListener', 'removeEventListener', {
          callbackid: callbackid
        }, function () {}); // 删除桥接层存储的监听回调方法

        bridge$1.removeCb(callbackid);

        if (global === '0') {
          delete window.__FOX_EVENT_CALLBACKS__[callbackid];
        }
      }
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2019-12-31 21:16:19
   * @Description: 设备信息
   */

  var nativeUI = {
    /**
     * @description 选择框actionsheet
     * @type {Function}
     * @param {String} data {"title":"这是一条actionSheet","cancel":"取消","buttons":["sheet1","sheet2","sheet3"]}
     * @returns {Number,String}  payload : {index : Number,content : String}
     */
    actionsheet: function (data, cb) {
      bridge$1.call('ActionSheet', 'actionSheet', data, cb);
    },

    /**
     * @description 显示等待进度条
     * @type {Function}
     * @param {String} msg 进度条显示文字描述
     * @returns
     */
    showWaiting: function (msg, cb) {
      bridge$1.call('Loading', 'showWaiting', msg, cb);
    },

    /**
     * @description 关闭进度条
     * @type {Function}
     * @param {String}
     */
    closeWaiting: function (cb) {
      bridge$1.call('Loading', 'closeWaiting', '', cb);
    },

    /**
     * @description 面包屑
     * @type {Function}
     * @param {String} msg 显示内容
     */
    toast: function (msg, cb) {
      bridge$1.call('Toast', 'toast', msg, cb);
    }
  };
  /*
   * @Author: tuyc3
   * @Date: 2020-04-30 11:29:42
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:49:00
   * @Description: 文字转语音
   */

  var voice = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    speaking: function (data, cb) {
      bridge$1.call('Voice', 'speaking', data, cb);
    }
  };
  /*
   * @Author: tuyc3
   * @Date: 2020-04-30 11:29:42
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:50:44
   * @Description: 用呗
   */

  var madcore = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    jumpMadCore: function (data, cb) {
      bridge$1.call('madcore', 'jumpMadCore', data, cb);
    }
  };
  /*
   * @Author: zhengchao
   * @Date: 2020-05-19 15:51:33
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:52:03
   * @Description: gesturelock 手势解锁
   */

  var gesture = {
    /**
     * 关闭手势解锁
     * 
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     * 
     */
    closeUnlock: function (data, cb) {
      bridge$1.call('Gesture', 'closeUnlock', data, cb);
    },

    /**
     * 手势解锁
     * 
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     * 
     */
    openUnlock: function (data, cb) {
      bridge$1.call('Gesture', 'openUnlock', data, cb);
    },

    /**
     * 关闭手势验证页面
     */
    closeUnlock: function (cb) {
      bridge$1.call('Gesture', 'closeUnlock', data, cb);
    },

    /**
     * 删除当前用户手势信息
     * 
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     * 
     */
    clearGestureInfo: function (data, cb) {
      bridge$1.call('Gesture', 'clearGestureInfo', data, cb);
    },

    /**
     * 获取当前用户手势数据
     * 
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     * 
     */
    currentGesture: function (data, cb) {
      bridge$1.call('Gesture', 'currentGesture', data, cb);
    },

    /**
     * 删除错误试错数据
     * 
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     * 
     */
    clearGestureErrorTimes: function (data, cb) {
      bridge$1.call('Gesture', 'clearGestureErrorTimes', data, cb);
    }
  };
  /*
   * @Author: zhengchao
   * @Date: 2020-06-18 15:17:18
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:53:18
   * @Description: 多语言
   */

  var language = {
    /**
     *多语言设置
     * 
     * {"language":"zh_CN","langMode":"1"};
     *   //1.设置后当前页面立即刷新语言生效，当前页面会重新加载，其他页面不刷新，getLang()方法在所有页面实时生效
        //2.设置后重启app，getLang()生效，页面语言生效
        //3.设置后页面不做刷新页面语言不会立即生效getLang()方法立即生效，需要杀掉进程重启app页面语言会生效，
     */
    setAppLanguage: function (data, cb) {
      bridge$1.call('Language', 'setAppLanguage', data, cb);
    },

    /**
     *获取当前app语言
     * 
     */
    getAppLanguage: function (cb) {
      bridge$1.call('Language', 'getAppLanguage', '', cb);
    },

    /**
     *获取当前app支持语言
     * 
     */
    getSupportLanguageList: function (cb) {
      bridge$1.call('Language', 'getSupportLanguageList', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:25:42
   * @LastEditors  : helin3
   * @LastEditTime : 2019-12-30 21:11:09
   * @Description: Webview
   */

  var router = {
    /**
     * 打开一个原生页面
     * @param {Object} data {
     * className: '类名',
     * params: {parsm1:"1"}参数
     * @param {Function} cb 回调
     * }
     */
    openNativePage: function (data, cb) {
      bridge$1.call('Router', 'openNativePage', data, cb);
    },

    /**
     * 切换首页的tab
     * index 页面下标
     */
    selectTab: function (data, cb) {
      bridge$1.call('Router', 'selectTab', data, cb);
    }
  };
  /*
   * @Author: zhoubingyu
   * @Date: 2020-05-20 17:29:42
   * @LastEditors: Aleyn He
   * @LastEditTime: 2020-07-18 16:33:27
   * @Description: 加密解密
   */

  var crypto = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    aes: function (data, cb) {
      bridge$1.call('EncryptDesEncrypt', 'aseAction', data, cb);
    }
  };
  var RecogType = {
    BACK: 0,
    FRONT: 1
  };
  var intsigocr = {
    /**
       * OCR识别类型
       */
    RecogType: RecogType,

    /**
     * @param {String} RecogType OCR识别类型
     * @param {Function} cb 回调
     * @returns
     * {Object} payload
     */
    startOCR: function (RecogType, cb) {
      var params = {
        positive: RecogType
      };
      bridge$1.call('IntSigOcr', 'startOCR', params, cb);
    }
  };
  var cfcakeyboard = {
    sm2: "sm2",
    rsa: "rsa",
    show: function (options, cb) {
      if (options === void 0) options = {};
      var data = {
        id: '',
        random: "MDEyMzQ1Njc4OWFiY2RlZg==",
        order: 1,
        keyType: 1,
        encryptFlag: 1,
        encryptType: "sm2"
      };

      _extends(data, options);

      console.log(data);
      bridge$1.call('CfcaKeyboard', 'openKeyboardNew', data, cb);
    },
    hide: function (id, cb) {
      var data = {
        id: id
      };
      bridge$1.call('CfcaKeyboard', 'closeKeyBoardNew', data, cb);
    },
    compare: function (id, confirmId, cb) {
      var data = {
        id: id,
        confirmId: confirmId
      };
      bridge$1.call('CfcaKeyboard', 'compareEditText', data, cb);
    }
  };
  var eyecoolface = {
    alive: function (cb) {
      bridge$1.call('EyeCoolFace', 'face', {}, cb);
    }
  }; // const options = {
  //   url: '',下载文件URL地址
  //   filename: '', // 下载文件保存的路径
  //   method: '', // 网络请求类型
  //   header: '', // 下载任务HTTP报文头
  //   success: function () {}, // 下载成功回调
  //   error: function () {}, // 下载失败回调
  //   data: {}, // POST请求时提交的数据
  //   timeout: 0, // 下载任务超时时间（暂不支持）
  //   priority: '', // 暂不支持
  //   retry: '', // 暂不支持
  //   retryInterval: '' // 暂不支持
  // };
  // let task = foxsdk.downloadfile.download(options);
  // task.start(); // 开始下载任务
  // task.pause(); // 暂停下载任务
  // task.resume(); // 开始下载任务
  // task.abort(); // 取消下载任务
  // task.stateChanged(); // 监听下载任务状态变化

  var download = function (options) {
    // 创建下载任务
    var task = downloader.createDownload(options.url, options, function (task) {
      var DownloadState = downloader.DownloadState;

      if (task.state == DownloadState.Finished) {
        options.success(task);
      } else {
        options.error(task);
      }
    });
    return task;
  };

  var downloadFile = {
    download: download,
    enumerate: downloader.enumerate,
    clear: downloader.clear,
    startAll: downloader.startAll,
    DownloadState: downloader.DownloadState
  }; // const options = {
  //   url: '', // 上传url
  //   chunkSize: '', // 分块上传时每次上传大小
  //   method: '', // 上传时请求方法
  //   header: '', // 上传请求头
  //   success: function () {}, // 上传成功回调
  //   error: function () {}, // 上传失败回调
  //   filePath: '', // 上传文件的路径
  //   fileAttr: {}, // 文件标识、文件名称、文件类型等
  //   formdata: {}, // 上传时参数
  //   addDataSuccess: function () {}, // 添加数据回调
  //   addFileSuccess: function () {}, // 添加文件回调
  //   priority: '', // 暂不支持
  //   timeout: '', // 暂不支持
  //   retry: '', // 暂不支持
  //   retryInterval: '', // 暂不支持
  //   blocksize: '' // 暂不支持
  // };
  // let task = foxsdk.uploadFile.upload(options);
  // task.start(); // 开始上传任务
  // task.pause(); // 暂停上传任务
  // task.resume(); // 开始上传任务
  // task.abort(); // 取消上传任务
  // task.stateChanged(); // 监听上传任务状态变化

  var judgeType = function (data, type) {
    return Object.prototype.toString.call(data).slice(8, -1).toLowerCase() === type;
  };

  var upload = function (options) {
    // 创建上传任务
    var task = uploader.createUpload(options.url, options, function (task) {
      var UploadState = uploader.UploadState;

      if (task.state == UploadState.Finished) {
        options.success(task);
      } else {
        options.error(task);
      }
    }); // 添加上传文件

    if (judgeType(options.filePath, 'array')) {
      options.filePath.forEach(function (path, index) {
        task.addFile(path, judgeType(options.fileAttr, 'array') && options.fileAttr[index] ? options.fileAttr[index] : {}, options.addFileSuccess ? options.addFileSuccess : function () {});
      });
    } else if (judgeType(options.filePath, 'string')) {
      task.addFile(options.filePath, options.fileAttr, options.addFileSuccess ? options.addFileSuccess : function (ret) {});
    } // 添加上传数据


    judgeType(options.formdata, 'object') && Object.keys(options.formdata).forEach(function (key) {
      task.addData(key, options.formdata[key], options.addDataSuccess ? options.addDataSuccess : function (ret) {});
    });
    return task;
  };

  var uploadFile = {
    upload: upload,
    UploadState: uploader.UploadState,
    enumerate: uploader.enumerate,
    clear: uploader.clear,
    startAll: uploader.startAll
  }; // const foxsdkv = function () {
  //     const fs = require('fs');
  //     const path = require('path')
  //     // var manifest = require('../manifest.json');
  //     logger.debug('jsl====----path====jsl'+path);
  //     logger.debug('jsl====__dirname====jsl'+__dirname);
  //     var manijsonpath= path.resolve(__dirname, '../')
  //     console.log('jsmmsm'+anijsonpath);
  //     // var contentText = fs.readFileSync('/Users/mac/p-yu-native/src/manifest.json','utf-8');
  //     // var manifestJson =  JSON.parse(contentText);
  //     // // alert(manifestJson)
  //     return  "v1.0.1"
  // }

  var foxsdkv = "v1.0.1";
  var xindun = {
    /**
     * 反欺诈-获取设备信息
     * @param {*} options 
     * @param {*} cb 
     */
    deviceInfo: function (cb) {
      bridge$1.call('XinDun', 'deviceInfo', '', cb);
    },

    /**
     * 反欺诈-设备预校验参数获取
     * @param {*} options 
     * {String} cstNo 用户号
     * @param {*} cb 
     */
    isUserInitialized: function (options, cb) {
      bridge$1.call('XinDun', 'isUserInitialized', options, cb);
    },

    /**
     * 反欺诈-獲取tokenA
     * @param {*} options 
     * {String} cstNo 用户号
     * @param {*} cb 
     */
    initByServerTokenGetTokenA: function (options, cb) {
      bridge$1.call('XinDun', 'initByServerTokenGetTokenA', options, cb);
    },

    /**
     * 反欺诈-设备解绑绑定关系校验
     * @param {*} options 
     * {String} cstNo 用户号
     * @param {*} cb 
     */
    deactivateUser: function (options, cb) {
      bridge$1.call('XinDun', 'deactivateUser', options, cb);
    },

    /**
     * 反欺诈-设备绑定
     * @param {*} options 
     * {String} cstNo 用户号
     *{String} tokenB 
     * @param {*} cb 
     */
    initByServerTokenFinish: function (options, cb) {
      bridge$1.call('XinDun', 'initByServerTokenFinish', options, cb);
    },

    /**
     * 反欺诈-短信加密
     * @param {*} options 
     * {String} cstNo 用户号
     * {String} message 
     * 
     * @param {*} cb 
     */
    getEncryptedTransactionInfo: function (options, cb) {
      bridge$1.call('XinDun', 'getEncryptedTransactionInfo', options, cb);
    },

    /**
     * 反欺诈-獲取tokenA
     * @param {*} options 
     * {String} cstNo 用户号
     * @param {*} cb 
     */
    getUUID: function (cb) {
      bridge$1.call('XinDun', 'getUUID', '', cb);
    }
  };
  var errorCode = {
    paramsError: {
      status: 10003,
      message: '调用参数不合法',
      payload: ''
    },
    router: {
      mustPassParamsIsNull: {
        status: 78001,
        message: '必要参数为空',
        payload: ''
      },
      paramsError: {
        status: 78002,
        message: '参数错误',
        payload: ''
      }
    },
    gesture: {
      paramsError: {
        status: 76001,
        message: '参数错误',
        payload: ''
      }
    },
    language: {
      paramsError: {
        status: 77001,
        message: '参数错误',
        payload: ''
      }
    },
    OCR: {
      paramEmpty: {
        code: '59000',
        message: '参数为空'
      }
    },
    webview: {
      mustPassParamsIsNull: {
        status: 11004,
        message: 'webview必传参数为空',
        payload: ''
      },
      paramsError: {
        status: 11003,
        message: 'webview参数错误',
        payload: ''
      }
    },
    DEVICE: {
      parmEmpty: {
        code: '73001',
        message: '必传参数为空'
      },
      paramError: {
        code: '73000',
        message: '参数错误'
      }
    },
    SCREEN: {
      parmEmpty: {
        code: '70000',
        message: '必传参数为空'
      },
      paramError: {
        code: '70001',
        message: '参数错误'
      }
    },
    EVENT: {
      EVENTREPEATBIND: {
        code: '69002',
        message: '事件监听上已绑定过当前回调，请勿重复绑定!'
      },
      EVENTNOSURPPORT: {
        code: '69001',
        message: '不支持的事件类型'
      }
    },
    BARCODE: {
      parmEmpty: {
        code: '68002',
        message: '必传参数为空'
      },
      paramError: {
        code: '68000',
        message: '参数错误'
      }
    },
    CLIPBOARD: {
      parmEmpty: {
        code: '80000',
        message: '必传参数为空'
      },
      paramError: {
        code: '80001',
        message: '参数错误'
      }
    },
    ZIP: {
      parmEmpty: {
        code: '67008',
        message: '必传参数为空'
      },
      paramError: {
        code: '67002',
        message: '参数错误'
      },
      PATHERROR: {
        code: '67007',
        message: '不支持此类文件系统'
      }
    },
    IO: {
      parmEmpty: {
        code: '61000',
        message: '必传参数为空'
      },
      paramError: {
        code: '61008',
        message: '参数错误'
      },
      PATHERROR: {
        code: '61010',
        message: '不支持此类文件系统'
      },
      NOTEXIST: {
        code: '61003',
        message: '文件或文件夹不存在'
      }
    },
    NATIVEUI: {
      parmEmpty: {
        code: '74001',
        message: '必传参数为空'
      },
      paramError: {
        code: '7200',
        message: '参数错误'
      }
    },
    AUDIO: {
      parmEmpty: {
        code: '79001',
        message: '必传参数为空'
      },
      paramError: {
        code: '79002',
        message: '参数错误'
      }
    },
    STORAGE: {
      parmEmpty: {
        code: '56000',
        message: '必传参数为空'
      },
      paramError: {
        code: '56003',
        message: '操作失败'
      },
      supportError: {
        code: '56001',
        message: '参数类型不支持'
      }
    },
    VOICE: {
      parmEmpty: {
        code: '74000',
        message: '必传参数为空'
      },
      paramError: {
        code: '74001',
        message: '参数错误'
      }
    },
    LOCATION: {
      parmEmpty: {
        code: '51007',
        message: '必传参数为空'
      },
      paramError: {
        code: '51005',
        message: '参数错误'
      }
    },
    FACE: {
      parmEmpty: {
        code: '62000',
        message: '必传参数为空'
      },
      paramError: {
        code: '62001',
        message: '参数错误'
      }
    },
    RUNTIME: {
      parmEmpty: {
        code: '58002',
        message: '必传参数为空'
      },
      urlError: {
        code: '58003',
        message: '在线文档url地址错误'
      },
      imgTypeError: {
        code: '58007',
        message: '截图图片格式错误'
      },
      paramError: {
        code: '58005',
        message: '参数错误'
      }
    },
    PUSH: {
      paramEmpty: {
        code: '57000',
        message: '参数为空'
      },
      paramError: {
        code: '57001',
        message: '参数错误'
      }
    },
    SHARE: {
      paramEmpty: {
        code: '64011',
        message: '参数为空'
      },
      paramError: {
        code: '64004',
        message: '参数错误'
      }
    },
    EVENTS: {
      paramEmpty: {
        code: '10003',
        message: '参数不合法'
      },
      paramError: {
        code: '69001',
        message: '参数错误'
      }
    }
  }; // 统一校验

  var Valid = {
    // 校验String类型
    validString: function (param) {
      return judgeType$1(param) === 'String';
    },
    // 校验Number类型
    validNumber: function (param) {
      return judgeType$1(param) === 'Number';
    },
    // 校验Object类型
    validObject: function (param) {
      return judgeType$1(param) === 'Object';
    },
    // 校验Array类型
    validArray: function (param) {
      return judgeType$1(param) === 'Array';
    },
    // 校验Function类型
    validFunction: function (param) {
      return judgeType$1(param) === 'Function';
    },
    // 校验boolean类型
    validBoolean: function (param) {
      return judgeType$1(param) === 'Boolean';
    },
    // 判断是否包含属性
    hasProperty: function (obj, key) {
      return Object.prototype.hasOwnProperty.call(obj, key);
    },
    //校验url格式
    validUrl: function (url) {
      if (!/^(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w\.-]+)+[\w\-\._~:/?#[\]@!\$&'\*\+,;=.]+$/.test(url)) {
        return false;
      }

      return true;
    }
  }; // 返回值类型

  var judgeType$1 = function (a) {
    return Object.prototype.toString.call(a).slice(8, -1);
  }; // 统一校验


  var ParamChecker = function (typeError, nullError, typeErrorMsg, nullErrorMsg) {
    this.errorCode = 0;
    this.message = '未检测到参数异常';
    this.typeError = typeError;
    this.nullError = nullError;
    this.typeErrorMsg = typeErrorMsg == null || typeErrorMsg === 'undefined' ? "参数类型错误  at_value " : typeErrorMsg + " at_value ";
    this.nullErrorMsg = nullErrorMsg == null || nullErrorMsg === 'undefined' ? "必要参数为空" : nullErrorMsg;
    var self = this; //校验必传参数

    this.checkString = function (p, compare) {
      return this.checkerParam("String", p, compare);
    }, this.checkNumber = function (p, compare) {
      return this.checkerParam('Number', p, compare);
    }, this.checkObject = function (p, compare) {
      return this.checkerParam('Object', p, compare);
    }, this.checkArray = function (p, compare) {
      return this.checkerParam('Array', p, compare);
    }, this.checkBoolean = function (p, compare) {
      return this.checkerParam('Boolean', p, compare);
    }, //校验非必传参数
    this.checkOptionalString = function (p, compare) {
      if (p == null || p === 'undefined') {
        return this;
      } else {
        return this.checkerParam("String", p, compare);
      }
    }, this.checkOptionalNumber = function (p, compare) {
      if (p == null || p === 'undefined') {
        return this;
      } else {
        return this.checkerParam('Number', p, compare);
      }
    }, this.checkOptionalBoolean = function (p, compare) {
      if (p == null || p === 'undefined') {
        return this;
      } else {
        return this.checkerParam('Boolean', p, compare);
      }
    }, this.checkOptionalObject = function (p, compare) {
      if (p == null || p === 'undefined') {
        return this;
      } else {
        return this.checkerParam('Object', p, compare);
      }
    }, this.checkOptionalArray = function (p, compare) {
      if (p == null || p === 'undefined') {
        return this;
      } else {
        return this.checkerParam('Array', p, compare);
      }
    }, this.checkerParam = function (type, p, compare) {
      if (self.errorCode != 0) {
        return self;
      }

      if (p == null || p === 'undefined') {
        this.errorCode = this.nullError;
        this.message = this.nullErrorMsg;
        return self;
      }

      var isLegale = true;

      if (compare) {
        isLegale = compare(p);
      }

      if (type == 'String') {
        if (!(Valid.validString(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }

        if (p.length == 0 && isLegale == true) {
          this.errorCode = this.nullError;
          this.message = this.nullErrorMsg + p;
        }
      } else if (type == 'Number') {
        if (!(Valid.validNumber(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }
      } else if (type == "Object") {
        if (!(Valid.validObject(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }
      } else if (type == 'Array') {
        if (!(Valid.validArray(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }
      } else if (type == 'Function') {
        if (!(Valid.validFunction(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }
      } else if (type == 'Boolean') {
        if (!(Valid.validBoolean(p) && isLegale == true)) {
          this.errorCode = this.typeError;
          this.message = this.typeErrorMsg + p;
        }
      } else {
        this.errorCode = this.typeError;
        this.message = this.typeErrorMsg + p;
      }

      return this;
    };
  };

  var SdkReponse = function (typeError, nullError) {
    this.status = '0', //statusCode 0  表示没有错误
    this.message = 'OK', this.payload = {};
  };

  var io$1 = {
    /**
     * 应用运行资源目录常量
     */
    PRIVATE_WWW: '1',

    /**
     * 应用私有文档目录常量
     */
    PRIVATE_DOC: '2',

    /**
     * 程序公用文档目录常量
     */
    PUBLIC_DOCUMENTS: '3',

    /**
     * 程序公用下载目录常量
     */
    PUBLIC_DOWNLOADS: '4',

    /**
     * 请求本地文件系统（返回绝对路径）
     *  PRIVATE_WWW:  _www/1
     *  PRIVATE_DOC:  _doc/2
     *  PUBLIC_DOCUMENTS:  _documents/3
     *  PUBLIC_DOWNLOADS:  _downloads/4
     * @param {Number} type 本地文件系统常量
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    requestFileSystem: function (type, successCb, failCb) {
      // console.log('type= ' + type);
      var sdkReponse = new SdkReponse();
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code);
      checker.checkString(type, function (u) {
        return u === '1' || u === '2' || u === '3' || u === '4';
      });

      if (checker.errorCode != 0) {
        sdkReponse.status = checker.errorCode;
        sdkReponse.message = checker.message;
        failCb && failCb(sdkReponse);
      } else {
        var pfsName = 'PRIVATE_WWW';
        var fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/www/';
        var absolutePath = '_www/'; // if (type === '1') {
        //     sdkReponse.payload = {
        //         "name": "www",
        //         "root": {
        //             "name": "www",
        //             "fullPath": "/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/www/",
        //             "remoteURL": "_www/"
        //         }
        //     }
        // }

        if (type === '2') {
          // sdkReponse.payload = {
          //         "name": "doc",
          //         "root": {
          //             "name": "doc",
          //             "fullPath": "/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/doc/",
          //             "remoteURL": "_doc/"
          //         }
          //     }
          pfsName = 'PRIVATE_DOC';
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/doc/';
          absolutePath = '_doc/';
        }

        if (type === '3') {
          // sdkReponse.payload = {
          //         "name": "documents",
          //         "root": {
          //             "name": "documents",
          //             "fullPath": "/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/documents/",
          //             "remoteURL": "_documents/"
          //         }
          //     }
          pfsName = 'PUBLIC_DOCUMENTS';
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/documents/';
          absolutePath = '_documents/';
        }

        if (type === '4') {
          // sdkReponse.payload = {
          //         "name": "downloads",
          //         "root": {
          //             "name": "downloads",
          //             "fullPath": "/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/downloads/",
          //             "remoteURL": "_downloads/"
          //         }
          //     }
          pfsName = 'PUBLIC_DOWNLOADS';
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/downloads/';
          absolutePath = '_downlods/';
        }

        var fs = new FileSystem$1(pfsName, fullPath, absolutePath);
        successCb && successCb(fs);
      }
    },

    /**
     * 将平台绝对路径转换成本地URL路径
     * @param {String} path 平台绝对路径，如：/var/xxx/doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 本地URL路径 _doc/xxx/xxx.txt
     */
    convertAbsoluteFileSystem: function (path, successCb, failCb) {
      // console.log('path= ' + path);
      var WWW_PATH = '/workspace/www/';
      var DOC_PATH = '/webapp/doc/';
      var DOCUMENTS_PATH = '/webapp/documents/';
      var DOWNLOADS_PATH = '/webapp/downloads/';
      var sdkReponse = new SdkReponse();
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code); // var checker1 = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code)

      checker.checkString(path);

      if (checker.errorCode == 0) {
        var absolutePath = '';
        var index = path.indexOf(WWW_PATH);
        var index1 = path.indexOf(DOC_PATH);
        var index2 = path.indexOf(DOCUMENTS_PATH);
        var index3 = path.indexOf(DOWNLOADS_PATH);

        if (index != -1) {
          var arrayPath = path.split(WWW_PATH);
          absolutePath = '_www/' + arrayPath[1];
        } else if (index1 != -1) {
          var arrayPath = path.split(DOC_PATH);
          absolutePath = '_doc/' + arrayPath[1];
        } else if (index2 != -1) {
          var arrayPath = path.split(DOCUMENTS_PATH);
          absolutePath = '_documents/' + arrayPath[1];
        } else if (index3 != -1) {
          var arrayPath = path.split(DOWNLOADS_PATH);
          absolutePath = '_downloads/' + arrayPath[1];
        }

        if (absolutePath.length == 0) {
          sdkReponse.status = errorCode.IO.PATHERROR.code;
          sdkReponse.message = errorCode.IO.PATHERROR.message;
          failCb && failCb(sdkReponse);
        } else {
          successCb && successCb(absolutePath);
        }
      } else {
        sdkReponse.status = checker.errorCode;
        sdkReponse.message = checker.message;
        failCb && failCb(sdkReponse);
      }
    },

    /**
     * 将平台绝对路径转换成本地URL路径
     * @param {String} path 平台绝对路径，如：/var/xxx/doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 本地URL路径 _doc/xxx/xxx.txt
     */
    convertLocalFileSystemURL: function (path, successCb, failCb) {
      // console.log('path= ' + path);
      var WWW_ABSOLUTE_HEAD = '_www/';
      var DOC_ABSOLUTE_HEAD = '_doc/';
      var DOCUMENTS_ABSOLUTE_HEAD = '_documents/';
      var DOWNLOADS_ABSOLUTE_HEAD = '_downloads/'; // const WWW_Full_Path = ''

      var sdkReponse = new SdkReponse();
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code); // var checker1 = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code)

      checker.checkString(path);

      if (checker.errorCode == 0) {
        var fullPath = '';
        var index = path.indexOf(WWW_ABSOLUTE_HEAD);
        var index1 = path.indexOf(DOC_ABSOLUTE_HEAD);
        var index2 = path.indexOf(DOCUMENTS_ABSOLUTE_HEAD);
        var index3 = path.indexOf(DOWNLOADS_ABSOLUTE_HEAD);

        if (index == 0) {
          var arrayPath = path.split(WWW_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/workspace/www/' + arrayPath[1];
        } else if (index1 == 0) {
          var arrayPath = path.split(DOC_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/doc/' + arrayPath[1];
        } else if (index2 == 0) {
          var arrayPath = path.split(DOCUMENTS_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/documents/' + arrayPath[1];
        } else if (index3 == 0) {
          var arrayPath = path.split(DOWNLOADS_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/downloads/' + arrayPath[1];
        }

        if (fullPath.length == 0) {
          sdkReponse.status = errorCode.IO.PATHERROR.code;
          sdkReponse.message = errorCode.IO.PATHERROR.message;
          failCb && failCb(sdkReponse);
        } else {
          successCb && successCb(fullPath);
        }
      } else {
        sdkReponse.status = checker.errorCode;
        sdkReponse.message = checker.message;
        failCb && failCb(sdkReponse);
      }
    },

    /**
     * 获取文件的系统名称PRIVATE_WWW、PRIVATE_DOC、PUBLIC_DOCUMENTS、PUBLIC_DOWNLOADS
     */
    getFilePfsName: function (remotePath) {
      var WWW_ABSOLUTE_HEAD = '_www/';
      var DOC_ABSOLUTE_HEAD = '_doc/';
      var DOCUMENTS_ABSOLUTE_HEAD = '_documents/';
      var DOWNLOADS_ABSOLUTE_HEAD = '_downloads/';
      var index = remotePath.indexOf(WWW_ABSOLUTE_HEAD);
      var index1 = remotePath.indexOf(DOC_ABSOLUTE_HEAD);
      var index2 = remotePath.indexOf(DOCUMENTS_ABSOLUTE_HEAD);
      var index3 = remotePath.indexOf(DOWNLOADS_ABSOLUTE_HEAD);
      var pfsName = 'remotePath';

      if (index == 0) {
        pfsName = 'PRIVATE_WWW';
      } else if (index1 == 0) {
        pfsName = 'PRIVATE_DOC';
      } else if (index2 == 0) {
        pfsName = 'PUBLIC_DOCUMENTS';
      } else if (index3 == 0) {
        pfsName = 'PUBLIC_DOWNLOADS';
      }

      return pfsName;
    },
    resolveLocalFileSystemURL: function (absolutePath, successCb, failCb) {
      // console.log('path= ' + absolutePath);
      var WWW_ABSOLUTE_HEAD = '_www/';
      var DOC_ABSOLUTE_HEAD = '_doc/';
      var DOCUMENTS_ABSOLUTE_HEAD = '_documents/';
      var DOWNLOADS_ABSOLUTE_HEAD = '_downloads/'; // const WWW_Full_Path = ''

      var sdkReponse = new SdkReponse();
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code); // var checker1 = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code)

      checker.checkString(absolutePath);

      if (checker.errorCode == 0) {
        var fullPath = '';
        var index = absolutePath.indexOf(WWW_ABSOLUTE_HEAD);
        var index1 = absolutePath.indexOf(DOC_ABSOLUTE_HEAD);
        var index2 = absolutePath.indexOf(DOCUMENTS_ABSOLUTE_HEAD);
        var index3 = absolutePath.indexOf(DOWNLOADS_ABSOLUTE_HEAD);
        var pfsName = 'PRIVATE_WWW';

        if (index == 0) {
          var arrayPath = absolutePath.split(WWW_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/workspace/www/' + arrayPath[1];
          pfsName = 'PRIVATE_WWW';
        } else if (index1 == 0) {
          var arrayPath = absolutePath.split(DOC_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/doc/' + arrayPath[1];
          pfsName = 'PRIVATE_DOC';
        } else if (index2 == 0) {
          var arrayPath = absolutePath.split(DOCUMENTS_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/documents/' + arrayPath[1];
          pfsName = 'PUBLIC_DOCUMENTS';
        } else if (index3 == 0) {
          var arrayPath = absolutePath.split(DOWNLOADS_ABSOLUTE_HEAD);
          fullPath = '/storage/emulated/0/Android/data/com.yusys.yump/files/webapp/downloads/' + arrayPath[1];
          pfsName = 'PUBLIC_DOWNLOADS';
        }

        if (fullPath.length == 0) {
          sdkReponse.status = errorCode.IO.PATHERROR.code;
          sdkReponse.message = errorCode.IO.PATHERROR.message;
          failCb && failCb(sdkReponse);
        } else {
          // PRIVATE_WWW、PRIVATE_DOC、PUBLIC_DOCUMENTS、PUBLIC_DOWNLOADS
          var fs = new FileSystem$1(pfsName, fullPath, absolutePath);
          var entry = new FileEntry$1(fullPath, absolutePath, fs);
          successCb && successCb(entry);
        }
      } else {
        sdkReponse.status = checker.errorCode;
        sdkReponse.message = checker.message;
        failCb && failCb(sdkReponse);
      }
    }
  };
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地目录
   * @param {Boolean} isDirectory
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */

  var FileEntry$1 = function (fullPath, remoteURL, fileSystem) {
    // console.log('fullPath 0= ' + fullPath);
    var lastIndex = fullPath.lastIndexOf('/'); // console.log('lastIndex 1= ' + lastIndex);

    if (fullPath.endsWith('/')) {
      fullPath = fullPath.substring(0, lastIndex); // console.log('fullPath 1= ' + fullPath);

      lastIndex = fullPath.lastIndexOf('/'); // console.log('lastIndex 2= ' + lastIndex);
    } // var lastIndex = fullPath.endsWith('/')


    this.name = fullPath.substring(lastIndex + 1);
    this.isDirectory = this.name.indexOf('.') == -1;
    this.isFile = !this.isDirectory;
    this.fullPath = fullPath;
    this.remoteURL = remoteURL;
    this.fileSystem = fileSystem;
  };
  /**
   * 文件操作对象，基于文件上的特有方法
   */


  _extends(FileEntry$1.prototype, {
    moveTo: function (dest, newName, successCb, failCb) {
      var WWW_ABSOLUTE_HEAD = '_www/';
      var DOC_ABSOLUTE_HEAD = '_doc/';
      var DOCUMENTS_ABSOLUTE_HEAD = '_documents/';
      var DOWNLOADS_ABSOLUTE_HEAD = '_downloads/';
      if (dest.indexOf(WWW_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOC_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOCUMENTS_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOWNLOADS_ABSOLUTE_HEAD) != 0) ;
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code);
      checker.checkString(dest, function (u) {
        var index1 = u.indexOf(WWW_ABSOLUTE_HEAD);
        var index2 = u.indexOf(DOC_ABSOLUTE_HEAD);
        var index3 = u.indexOf(DOCUMENTS_ABSOLUTE_HEAD);
        var index4 = u.indexOf(DOWNLOADS_ABSOLUTE_HEAD);
        console.log(' index1 ' + index1 + ' index2 ' + index2 + ' index3 ' + index3 + ' index4 ' + index4);
        return u.indexOf(WWW_ABSOLUTE_HEAD) == 0 || u.indexOf(DOC_ABSOLUTE_HEAD) == 0 || u.indexOf(DOCUMENTS_ABSOLUTE_HEAD) == 0 || u.indexOf(DOWNLOADS_ABSOLUTE_HEAD) == 0;
      });
      checker.checkString(newName, function (u) {
        console.log(' checkstring u= ' + u + " boolean value " + (null == u || u.length == 0 || u.lastIndexOf('.') == -1 || u.indexOf('/') != -1));
        return null != u && u.length != 0 && u.lastIndexOf('.') != -1 && u.indexOf('/') == -1;
      });
      var sdkReponse = new SdkReponse();

      if (checker.errorCode != 0) {
        sdkReponse.status = errorCode.IO.PATHERROR.code;
        sdkReponse.message = errorCode.IO.PATHERROR.message;
        failCb && failCb(sdkReponse);
        return;
      }

      var remoteDest = dest + '/' + newName;

      if (dest.endsWith('/')) {
        remoteDest = dest + newName;
      }

      io$1.convertLocalFileSystemURL(remoteDest, function (fullPath) {
        var fileSystem = new FileSystem$1(io$1.getFilePfsName(remoteDest), fullPath, remoteDest);
        var fileEntry = new FileEntry$1(fullPath, remoteDest, fileSystem);
        successCb(fileEntry);
      }, function (failEntry) {
        failCb(failEntry);
      });
    },
    remove: function (successCb, failCb) {
      var sdkReponse = new SdkReponse();
      successCb(sdkReponse);
    },
    copyTo: function (dest, newName, successCb, failCb) {
      var this$1 = this;
      var WWW_ABSOLUTE_HEAD = '_www/';
      var DOC_ABSOLUTE_HEAD = '_doc/';
      var DOCUMENTS_ABSOLUTE_HEAD = '_documents/';
      var DOWNLOADS_ABSOLUTE_HEAD = '_downloads/';
      if (dest.indexOf(WWW_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOC_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOCUMENTS_ABSOLUTE_HEAD) != 0 || dest.indexOf(DOWNLOADS_ABSOLUTE_HEAD) != 0) ;
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code);
      checker.checkString(dest, function (u) {
        var index1 = u.indexOf(WWW_ABSOLUTE_HEAD);
        var index2 = u.indexOf(DOC_ABSOLUTE_HEAD);
        var index3 = u.indexOf(DOCUMENTS_ABSOLUTE_HEAD);
        var index4 = u.indexOf(DOWNLOADS_ABSOLUTE_HEAD);
        console.log(' index1 ' + index1 + ' index2 ' + index2 + ' index3 ' + index3 + ' index4 ' + index4);
        return u.indexOf(WWW_ABSOLUTE_HEAD) == 0 || u.indexOf(DOC_ABSOLUTE_HEAD) == 0 || u.indexOf(DOCUMENTS_ABSOLUTE_HEAD) == 0 || u.indexOf(DOWNLOADS_ABSOLUTE_HEAD) == 0;
      });
      checker.checkString(newName, function (u) {
        console.log(' checkstring u= ' + u + " boolean value " + (null == u || u.length == 0 || u.lastIndexOf('.') == -1 || u.indexOf('/') != -1));

        if (this$1.isFile) {
          return null != u && u.length != 0 && u.lastIndexOf('.') != -1 && u.indexOf('/') == -1;
        } else {
          return null != u && u.length != 0 && u.lastIndexOf('.') == -1 && u.indexOf('/') == -1;
        }
      });
      var sdkReponse = new SdkReponse();

      if (checker.errorCode != 0) {
        sdkReponse.status = errorCode.IO.PATHERROR.code;
        sdkReponse.message = errorCode.IO.PATHERROR.message;
        failCb && failCb(sdkReponse);
        return;
      }

      var remoteDest = dest + '/' + newName;

      if (dest.endsWith('/')) {
        remoteDest = dest + newName;
      }

      io$1.convertLocalFileSystemURL(remoteDest, function (fullPath) {
        var fileSystem = new FileSystem$1(io$1.getFilePfsName(remoteDest), fullPath, remoteDest);
        var fileEntry = new FileEntry$1(fullPath, remoteDest, fileSystem);
        successCb(fileEntry);
      }, function (failEntry) {
        failCb(failEntry);
      });
    },
    getMetadata: function (successCb, failCb, recursive) {
      var sdkReponse = new SdkReponse();
      sdkReponse.payload = {
        size: 145236,
        modificationTime: 1616554754000,
        directoryCount: this.isFile ? '0' : '12',
        fileCount: this.isFile ? 0 : 12
      };
      successCb(sdkReponse.payload);
    },
    getFileDigestInfo: function (digestAlgorithm, successCb, failCb) {
      if (this.isFile) ;
      var sdkReponse = new SdkReponse();
      sdkReponse.payload = {
        size: 10393062,
        digest: '30dea1dd2e7070752816caafddcdd1aa'
      };
      successCb(sdkReponse.payload);
    },
    getFile: function (path, flat, successCb, failCb) {
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code);
      checker.checkString(path, function (u) {
        return u.length > 0 && u.lastIndexOf('/') > u.lastIndexOf('.');
      });
      var sdkReponse = new SdkReponse();

      if (checker.errorCode != 0) {
        sdkReponse.status = errorCode.IO.PATHERROR.code;
        sdkReponse.message = errorCode.IO.PATHERROR.message;
        failCb && failCb(sdkReponse);
        return;
      }

      var fullPath = this.fullPath + '/' + path;
      var remotePath = this.remotePath + '/' + path;
      console.log(' fullPath ' + this.fullPath);

      if (this.fullPath.endsWith('/')) {
        if (path.indexOf('/') == 0) {
          fullPath = this.fullPath + path.substring(1);
        } else {
          fullPath = this.fullPath + path;
        }
      } else {
        if (path.indexOf('/') == 0) {
          fullPath = this.fullPath + path;
        } else {
          fullPath = this.fullPath + '/' + path.substring(1);
        }
      }

      if (this.remoteURL.indexOf('/') == this.remoteURL.length - 1) {
        if (path.indexOf('/') == 0) {
          remotePath = this.remoteURL + path.substring(1);
        } else {
          remotePath = this.remoteURL + path;
        }
      } else {
        if (path.indexOf('/') == 0) {
          remotePath = this.remoteURL + path;
        } else {
          remotePath = this.remoteURL + '/' + path.substring(1);
        }
      }

      var fileSystem = new FileSystem$1(io$1.getFilePfsName(remotePath), fullPath, remotePath);
      var fileEntry = new FileEntry$1(fullPath, remotePath, fileSystem);
      successCb(fileEntry);
    },
    getDirectory: function (path, flat, successCb, failCb) {
      var checker = new ParamChecker(errorCode.IO.paramError.code, errorCode.IO.parmEmpty.code);
      checker.checkString(path, function (u) {
        return u.length > 0 && u.lastIndexOf('/') < u.lastIndexOf('.');
      });
      var sdkReponse = new SdkReponse();

      if (checker.errorCode != 0) {
        sdkReponse.status = errorCode.IO.PATHERROR.code;
        sdkReponse.message = errorCode.IO.PATHERROR.message;
        failCb && failCb(sdkReponse);
        return;
      }

      var fullPath = this.fullPath + '/' + path;
      var remotePath = this.remotePath + '/' + path;
      console.log(' fullPath ' + this.fullPath);

      if (this.fullPath.endsWith('/')) {
        if (path.indexOf('/') == 0) {
          fullPath = this.fullPath + path.substring(1);
        } else {
          fullPath = this.fullPath + path;
        }
      } else {
        if (path.indexOf('/') == 0) {
          fullPath = this.fullPath + path;
        } else {
          fullPath = this.fullPath + '/' + path.substring(1);
        }
      }

      if (this.remoteURL.indexOf('/') == this.remoteURL.length - 1) {
        if (path.indexOf('/') == 0) {
          remotePath = this.remoteURL + path.substring(1);
        } else {
          remotePath = this.remoteURL + path;
        }
      } else {
        if (path.indexOf('/') == 0) {
          remotePath = this.remoteURL + path;
        } else {
          remotePath = this.remoteURL + '/' + path.substring(1);
        }
      }

      var fileSystem = new FileSystem$1(io$1.getFilePfsName(remotePath), fullPath, remotePath);
      var fileEntry = new FileEntry$1(fullPath, remotePath, fileSystem);
      successCb(fileEntry);
    }
  });
  /**
   * 文件系统定义（支持4种）
   * @param {String} name 文件系统名称
   * PRIVATE_WWW、PRIVATE_DOC
   * PUBLIC_DOCUMENTS、PUBLIC_DOWNLOADS
   * @param {Object} root {name, fullPath, remoteURL}
   */


  var FileSystem$1 = function (name, fullPath, remoteURL) {
    // console.log(' fielSystem fullPath ' + fullPath + ' remoteURL ' + remoteURL)
    this.name = name || null;
    var rootFullPath = fullPath; // if (-1 == fullPath.indexOf('.')) {
    //     if (fullPath.endsWith('/')) {
    //         fullPath = fullPath.substring(0, lastIndex)
    //         lastIndex = fullPath.lastIndexOf('/')
    //     }
    //     // rootFullPath  = fullPath.substring(0, lastIndex)
    // }
    // console.log(' fielSystem rootFullPath1 ' + rootFullPath)

    var indexPoint = fullPath.lastIndexOf('.');
    var indexSlash = fullPath.lastIndexOf('/');

    if (indexPoint != -1 && indexPoint > indexSlash) {
      var lastIndex = fullPath.lastIndexOf('/');
      rootFullPath = fullPath.substring(0, lastIndex + 1); // console.log(' fielSystem fullPath.indexOf . ' + fullPath.indexOf('.'))
    } // var lastIndex = fullPath.lastIndexOf('/')
    // var parentDirFullPath = fullPath.substring(0, lastIndex)
    // console.log(' fielSystem rootFullPath ' + rootFullPath)


    var remoteRootFullPath = remoteURL;
    var indexRemotePoint = remoteURL.lastIndexOf('.');
    var indexRemoteSlash = remoteURL.lastIndexOf('/');

    if (indexRemotePoint != -1 && indexRemotePoint > indexRemoteSlash) {
      var lastIndex = remoteURL.lastIndexOf('/');
      remoteRootFullPath = remoteURL.substring(0, lastIndex + 1);
    } //这是父文件的文件对象


    this.root = new FileEntry$1(rootFullPath, remoteRootFullPath);
  };
  /**
     * 下载任务列表
     */


  var __DOWNLOAD_TASK_LIST__$1 = {};
  /**
     * 下载状态
     */

  var DownloadState$1 = {
    /**
     * 下载任务未开始
     */
    Undefined: -1001,

    /**
     * 所有下载任务
     */
    All: -1,

    /**
     * 下载任务开始调度
     */
    Start: 0,

    /**
     * 下载任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 下载任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 下载任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 下载任务已完成（成功）
     */
    Finished: 4,

    /**
     * 下载任务已暂停
     */
    Pause: 5,

    /**
     * 下载任务发生异常
     */
    Error: 6
  };
  /**
    * 上传任务结束时调用（任务完成、任务取消、清除）
    * @param {Object} UploadTask 上传任务对象
    * @param {Object} resonse {status,message} 返回对象
    */

  var deleteTask$2 = function (task) {
    delete __DOWNLOAD_TASK_LIST__$1[task.identify];
  };
  /**
   * 下载任务对象
   */


  var DownloadTask$1 = function (options) {
    /**
     * 下载任务TaskId
     */
    this.identify = 'taksId123456788';
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 网络请求类型
     * 支持http协议的“GET”、“POST”，默认为“GET”请求。
     */

    this.method = this.options.method || 'get';
    /**
     * POST请求时提交的数据
     * 仅在网络请求类型method设置为"POST"时有效，"GET"请求时忽略此数据。
     */

    this.data = this.options.data || '';
    /**
     * 设置下载请求的HTTP头数据
     */

    this.header = this.options.header || {};
    /**
     * 下载文件保存的路径
     * 保存文件路径仅支持以"_downloads/"、"_doc/"、"_documents/"开头的字符串。
     * 文件路径以文件后缀名结尾（如"_doc/download/a.doc"）表明指定保存文件目录及名称，
     * 以“/”结尾则认为指定保存文件的目录（此时程序自动生成文件名）。
     * 默认保存目录为（"_downloads"），并自动生成文件名称。
     */

    this.filename = this.options.filename || '_downloads/';
    /**
     * 下载任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是下载任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 下载任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 下载任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 下载任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.totalSize = 0;
    this.downloadedSize = 0;
    /**
     * 下载任务当前状态
     */

    this.state = -1001;
    /**
     * 下载任务完成回调
     * @param {DownloadTask} task 下载任务对象
     */

    this.completedCb = options.completedCb || function (task) {};
    /**
     * 下载任务状态变化时执行的回调
     * @param {DownloadTask} task 下载任务对象
     */


    this.stateChangeCb = function (task) {};
  };

  _extends(DownloadTask$1.prototype, {
    /**
     * 开始下载任务
     */
    start: function () {
      var _this = this;

      var sdkR = new SdkReponse();

      if (_this.state != DownloadState$1.Undefined) {
        sdkR.status = '60012';
        sdkR.message = '任务不是非开始状态，不能开始下载';
        sdkR.payload = {};

        _this.completedCb(sdkR);
      } else {
        _this.state = DownloadState$1.ReadReceived;
        sdkR.status = '0';
        sdkR.message = '开始下载';
        sdkR.payload = _this;

        _this.completedCb(sdkR);

        if (_this.stateChanged) {
          sdkR.status = '1';
          sdkR.message = '持续监听中';
          sdkR.payload = _this;

          _this.stateChanged(message);
        }
      }
    },

    /**
     * 暂停下载任务
     */
    pause: function () {
      var _this = this;

      var sdkR = new SdkReponse();

      if (_this.state != DownloadState$1.ReadReceived) {
        sdkR.status = '60014';
        sdkR.message = '任务不是下载中,不能暂停';
        sdkR.payload = {};

        _this.completedCb(sdkR);
      } else {
        _this.state = DownloadState$1.Pause;
        sdkR.message = '任务已暂停';
        sdkR.payload = _this;

        _this.completedCb(sdkR);

        if (_this.stateChanged) {
          sdkR.status = '1';
          sdkR.message = '持续监听中';
          sdkR.payload = _this;

          _this.stateChanged(message);
        }
      }
    },

    /**
     * 恢复下载任务
     */
    resume: function () {
      var _this = this;

      var sdkR = new SdkReponse();

      if (_this.state != DownloadState$1.Pause) {
        sdkR.status = '60013';
        sdkR.message = '任务不是暂停状态,不能恢复下载';
        sdkR.payload = {};

        _this.completedCb(sdkR);
      } else {
        _this.state = DownloadState$1.ReadReceived;
        sdkR.message = '任务已恢复';
        sdkR.payload = _this;

        _this.completedCb(sdkR);

        if (_this.stateChanged) {
          sdkR.status = '1';
          sdkR.message = '持续监听中';
          sdkR.payload = _this;

          _this.stateChanged(message);
        }
      }
    },

    /**
     * 取消下载任务，
     */
    abort: function () {
      var _this = this;

      _this.state = DownloadState$1.Finished;
      var sdkR = new SdkReponse();
      sdkR.message = '任务已取消';
      sdkR.payload = _this;

      _this.completedCb(sdkR);

      deleteTask$2(_this.identify);
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 下载任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    }
  });
  /*
     * @Author: helin3
     * @Date: 2020-01-07 15:23:13
     * @LastEditors: Aleyn He
     * @LastEditTime: 2020-07-18 16:42:06
     * @Description: 文件上传
     */


  var logger$3$1 = utils.logger;
  var NATIVE_STATUS_CODE$3$1 = utils.NATIVE_STATUS_CODE;
  /**
   * 上传任务列表
   */

  var __UPLOAD_TASK_LIST__$1 = {};
  /**
   * 上传状态
   */

  var UploadState$1 = {
    /**
     * 上传任务未开始
     */
    Undefined: -1001,

    /**
     * 枚举任务状态
     */
    All: -1,

    /**
     * 上传任务开始调度
     */
    Start: 0,

    /**
     * 上传任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 上传任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 上传任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 上传任务已完成（成功）
     */
    Finished: 4,

    /**
     * 上传任务已暂停
     */
    Pause: 5,

    /**
     * 上传任务发生异常
     */
    Error: 6
  };
  /**
   * 上传任务对象
   */

  var UploadTask$1 = function (options) {
    /**
     * 上传任务TaskId
     */
    this.identify = utils.uuid('utask');
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 上传任务每次上传的文件块大小（仅在支持断点续传的服务有效）
     * 数值类型，单位为Byte（字节），默认值为102400，若设置值小于等于0则表示不分块上传
     */

    this.blocksize = this.options.blocksize || 0;
    /**
     * 分块上传的大小
     * 单位为Kb，设置值小于等于0则不分块上传，默认为不分块上传
     * Android平台需设置分块上传才能准确触发statechanged返回上传进度，
     * 如果不设置分块上传则在开始后快速返回上传完成进度，而实际并没有上传完。
     * 注意：分块上传需要服务器支持，如果服务器不支持则会删除失败。
     */

    this.chunkSize = this.options.blocksize || 0;
    /**
     * 网络请求类型
     * 仅支持http协议的“POST”
     */

    this.method = this.options.method || 'POST';
    /**
     * 上传任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是上传任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 上传任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 上传任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 上传任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.header = this.options.header || '';
    this.formData = '';
    /**
     * 上传任务完成后服务器返回的数据
     */

    this.responseText = '';
    /**
     * 已完成上传数据的大小
     */

    this.uploadedSize = 0;
    /**
     * 上传数据的总大小
     */

    this.totalSize = 0;
    /**
     * 上传任务当前状态
     */

    this.state = -1001;
    /**
     * 上传任务完成回调
     * @param {UploadTask} task 上传任务对象
     */

    this.completedCb = this.options.completedCb || function (task) {};
    /**
     * 上传任务状态变化时执行的回调
     * @param {UploadTask} task 上传任务对象
     */


    this.stateChangeCb = function (task) {};
  };
  /**
   * 上传任务结束时调用（任务完成、任务取消、清除）
   * @param {Object} UploadTask 上传任务对象
   * @param {Object} resonse {status,message} 返回对象
   */


  var deleteTask$1$1 = function (task) {
    delete __UPLOAD_TASK_LIST__$1[task.identify];
  };
  /**
   * 监听上传任务状态回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerCallback.call(task, options);
   */


  var handlerCallback$1$1 = function (options) {
    options = options || {};
    this.state = options.state || this.state;
    this.responseText = options.responseText || this.responseText;
    this.uploadedSize = options.uploadedSize || this.uploadedSize;
    this.totalSize = options.totalSize || this.totalSize;
    this.status = options.status;
    this.message = options.message;
    this.payload = options.payload; // identify
    // url
    // options
    // 上传任务状态变化回调函数，在上传任务状态发生变化时调用

    this.stateChangeCb(this); // 上传任务完成清除上传任务队列

    this.state == UploadState$1.Finished && deleteTask$1$1(this); // 上传任务完成、上传任务失败，都调用业务回调
    // if (this.state == UploadState.Finished ||
    //     this.state == UploadState.Error) {

    this.completedCb(this); // }
  };
  /**
   * UploadState.Finished 上传任务完成，该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * UploadState.Error 上传任务发生异常，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var addStateChange$1$1 = function (task) {
    bridge.call('Uploader', 'stateChanged', {
      identify: task.identify
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$3$1.OK || status === NATIVE_STATUS_CODE$3$1.PROCESS) {
        handlerCallback$1$1.call(task, payload.upload);
      } else {
        deleteTask$1$1(task);
        logger$3$1.debug('====uploader-stateChanged====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };

  _extends(UploadTask$1.prototype, {
    /**
     * 添加上传文件
     * @param {String} path
     * @param {UploadFileOption} options
     * key: (String 类型 )文件键名
     * 上传文件在上传任务中的键名，默认值为为文件名称。
     * 上传任务中如果已经存在相同key的上传文件或数据将导致添加文件失败。
     * name: (String 类型 )文件名称
     * 上传文件的名称，默认值为上传文件路径中的名称。
     * mime: (String 类型 )文件类型
     * 上传文件的类型（如图片文件为“image/jpeg”），默认值自动根据文件后缀名称生成。可不传值
     * @param {Function} cb 回调
     */
    addFile: function (path, options, cb) {
      var _this = this;

      var data = {
        path: path,
        options: options,
        identify: _this.identify
      };
      dataMake.call('Uploader', 'addFile', data, cb);
    },

    /**
     * 加上传数据
     * @param {String} key 键名
     * @param {String} value 值
     * @param {Function} cb 回调
     * @returns
     */
    addData: function (key, value, cb) {
      var _this = this;

      var data = {
        key: key,
        value: value,
        identify: _this.identify
      };
      dataMake.call('Uploader', 'addData', data, cb);
    },

    /**
     * 开始上传任务
     */
    start: function () {
      var _this = this;

      dataMake.call('Uploader', 'start', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === '0') {
          logger$3$1.debug('开始上传');
          handlerCallback$1$1.call(_this, payload.upload);
        } else {
          logger$3$1.debug('====uploader-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停上传任务
     */
    pause: function () {
      var _this = this;

      dataMake.call('Uploader', 'pause', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === '0') {
          logger$3$1.debug('暂停上传');
          handlerCallback$1$1.call(_this, payload.upload);
        } else {
          logger$3$1.debug('====uploader-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复上传任务
     */
    resume: function () {
      var _this = this;

      dataMake.call('Uploader', 'resume', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === '0') {
          logger$3$1.debug('恢复上传');
          handlerCallback$1$1.call(_this, payload.upload);
        } else {
          logger$3$1.debug('====uploader-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 取消上传任务，
     */
    abort: function () {
      var _this = this;

      dataMake.call('Uploader', 'abort', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === '0') {
          logger$3$1.debug('取消上传');
          handlerCallback$1$1.call(_this, payload.upload);
          deleteTask$1$1(_this);
        } else {
          logger$3$1.debug('====uploader-abort====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 上传任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    },

    /**
    * 开始所有上传任务
    */
    startAll: function () {
      bridge.call('Uploader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3$1.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__$1[upload.identify];

            if (!task) {
              task = new UploadTask$1(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1$1.call(task, upload);
            addStateChange$1$1(task);
          });
        } else {
          logger$3$1.debug('====uploader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + JSON.stringify(payload));
        }
      });
    }
  });

  var dataMake = {
    call: function (cName, fName, data, callbcak) {
      var dataMakeReponse = new SdkReponse();

      if (cName == 'Uploader' && fName == 'createUpload') {
        data.options = {
          '111': '1111'
        };
        dataMakeReponse.payload = {
          'identify': '',
          'url': '',
          'state': 1,
          'options': {
            '11': '1',
            'responseText': '',
            'uploadedSize': '0B',
            'totalSize': '132213123B'
          }
        };
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'addFile') {
        dataMakeReponse.payload = '';
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'addData') {
        dataMakeReponse.payload = '';
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'start') {
        data.options = {
          '111': '1111'
        };
        dataMakeReponse.payload = data;
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'pause') {
        dataMakeReponse.payload = data;
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'resume') {
        dataMakeReponse.payload = data;
        callbcak(dataMakeReponse);
      }

      if (cName == 'Uploader' && fName == 'abort') {
        dataMakeReponse.payload = data;
        callbcak(dataMakeReponse);
      }
    }
  };
  // console.log(errorCode);
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:18:23
   * @LastEditors: Aleyn He
   * @Description: 导出native方法
   */

  var logger$6 = utils.logger;
  var sdk = {
    call: bridge$1.call,
    logger: logger$6,
    http: http,
    downloader: downloader,
    uploader: uploader,
    device: device,
    networkinfo: networkinfo,
    screen: screen,
    storage: storage,
    clipboard: clipboard,
    runtime: runtime,
    io: io,
    zip: zip,
    key: key,
    pwdkey: pwdkey,
    gallery: gallery,
    camera: camera,
    audio: audio,
    contacts: contacts,
    webview: webview,
    touchid: touchid,
    voice: voice,
    madcore: madcore,
    barcode: barcode,
    location: location,
    share: share,
    push: push,
    ocr: ocr,
    face: face,
    events: events,
    nativeUI: nativeUI,
    gesture: gesture,
    crypto: crypto,
    language: language,
    router: router,
    intsigocr: intsigocr,
    cfcakeyboard: cfcakeyboard,
    eyecoolface: eyecoolface,
    downloadfile: downloadFile,
    uploadfile: uploadFile,
    jssdkversion: foxsdkv,
    xindun: xindun
  };
  window.__FOX_NATIVE_EVAL__ = bridge$1.nativeEval; // 开发调式模式将foxsdk绑定到window上，供app-fox和uni-stat使用原生全局对象
  // trycatch是为避免浏览器环境报错

  try {
    process.env.NODE_ENV === 'development' ? window.foxsdk = sdk : void 0;
  } catch (e) {}

  return sdk;
});
